clear all

global data_dir "./data" 
global sav_dir "./output" 

********************************************************************************
* Table 1
********************************************************************************

* 1962 SFCC

use "${data_dir}/SFCC_1962.dta", clear

	foreach dvar in tinc nw {
	
	qui gen `dvar'_top10 = 0
	qui gen `dvar'_top5 = 0
				
	* compute percentiles
	qui _pctile `dvar' [aw = wgt], p(90 95)

	local P90 = `r(r1)'
	local P95 = `r(r2)'

	qui replace `dvar'_top10 = 1 if `dvar' > `P90' & `dvar' < .
	qui replace `dvar'_top5 = 1 if `dvar' > `P95' & `dvar' < .

	}
	
sum highsample if tinc_top10 == 1 [aw = wgt]
sum highsample if tinc_top5 == 1 [aw = wgt]
sum highsample if nw_top10 == 1 [aw = wgt]
sum highsample if nw_top5 == 1 [aw = wgt]

* 1983 SCF

use "${data_dir}/SCF_plus.dta", clear

keep if year == 1983
rename ffanw nw

	foreach dvar in tinc nw {
	
	qui gen `dvar'_top10 = 0
	qui gen `dvar'_top5 = 0
				
	* compute percentiles
	qui _pctile `dvar' [aw = wgt], p(90 95)

	local P90 = `r(r1)'
	local P95 = `r(r2)'

	qui replace `dvar'_top10 = 1 if `dvar' > `P90' & `dvar' < .
	qui replace `dvar'_top5 = 1 if `dvar' > `P95' & `dvar' < .

	}
	
sum highsample if tinc_top10 == 1 [aw = wgt]
sum highsample if tinc_top5 == 1 [aw = wgt]
sum highsample if nw_top10 == 1 [aw = wgt]
sum highsample if nw_top5 == 1 [aw = wgt]

********************************************************************************
* Figures 1 + A.1
********************************************************************************
	
tempfile shares

use "${data_dir}/SCF_plus.dta", clear	

qui gen myear_ind = 1 if inrange(yearmerge, 1950, 1990)

qui gen agehgroup2 = (agehgroup == 2) // 25-34
qui gen agehgroup6 = (agehgroup == 6) // 65-99
qui gen homeown = (house > 0) if house != .

preserve

local collvars = ""
	foreach var in homeown blackh collegeh agehgroup2 agehgroup6 { // vars for collapse (new weights)
	local collvars = "`collvars' share_`var'_wgt = `var'"
	} // var

qui collapse `collvars' myear_ind [aw=wgtI95W95], by(yearmerge)
qui save `shares', replace

restore

local collvars = ""
	foreach var in homeown blackh collegeh agehgroup2 agehgroup6 { // vars for collapse (old weights)
	local collvars = "`collvars' share_`var'_oldwgt = `var'"
	} // var

qui collapse `collvars' [aw=wgt], by(yearmerge)

qui merge 1:1 yearmerge using `shares', nogen
qui save `shares', replace

* homeownership
qui use "${data_dir}/census_data/census_homeowner.dta", clear
keep if homeowner == 1
qui keep CShomeowner yearmerge
merge 1:1 yearmerge using `shares', nogen
qui save `shares', replace

* blackh
qui use "${data_dir}/census_data/census_blackh.dta", clear
qui keep if blackh == 1
qui keep CSblackh yearmerge
qui merge 1:m yearmerge using `shares', nogen
qui save `shares', replace

* collegeh
qui use "${data_dir}/census_data/census_collegeh.dta", clear
qui keep if collegeh == 1
qui keep CScollegeh yearmerge
qui merge 1:m yearmerge using `shares', nogen
qui save `shares', replace

* ageh
qui use "${data_dir}/census_data/census_agehgroup.dta", clear
qui keep if inlist(agehgroup, 2, 6)
qui drop year
qui reshape wide CSagehgroup, i(yearmerge) j(agehgroup)
qui merge 1:m yearmerge using `shares', nogen
qui save `shares', replace

qui keep if inrange(yearmerge, 1950, 1990)
qui keep if myear_ind == 1 | (mod(yearmerge, 10) == 0)

	foreach var in homeown blackh collegeh agehgroup2 agehgroup6 {
	
	if "`var'" == "homeown" {
	local yrng = "0.2 0.9"
	local ylab = "0.2(0.1)0.9"
	}
	else if "`var'" != "homwown" {
	local yrng = "0 0.5"
	local ylab = "0(0.1)0.5"
	}
	
	twoway connected CS`var' yearmerge if (mod(yearmerge, 10) == 0), ///
	msym(s) msize(medlarge) mfc(gs0) mlc(gs0) || ///
	scatter share_`var'_oldwgt yearmerge if myear_ind == 1, msym(o) msize(large) mfc(red) mlc(red) || ///
	scatter share_`var'_wgt yearmerge if myear_ind == 1, msym(d) msize(medlarge) mfc(blue) mlc(blue) ///
	plotregion(color(white)) graphregion(color(white)) bgcolor(white) ///
	xscale(r(1950 1990)) xlabel(1950(3)1990, angle(45)) yscale(r(`yrng')) ///
	ylabel(`ylab', angle(0)) xtitle("") ytitle("") ///
	legend(ring(0) position(10) col(1) lab(1 "Census share") lab(2 "SCF+ share without adjustment") ///
	lab(3 "SCF+ share with adjustment")) name("comp_census_`var'", replace) 
	graph export "${sav_dir}/comp_census_`var'.eps", replace
	} // var

********************************************************************************
* Figures 2 + 3
********************************************************************************

*-------------------------------------------------------------------------------
* SCF and NIPA comparison 
*-------------------------------------------------------------------------------
clear
set more off

tempfile NIPA69 NIPA29 households NIPA312 NIPA112 NIPA711 NIPA79 NIPA710

local SCFyears "1948/1971 1977 1983(3)2016"

/* Read in NIPA data table 2.1 for 1969 - 2017 */
import excel using "${data_dir}/aggregate_data/NIPA21.xlsx", sheet("NIPA 1969") firstrow cellra(A2:AU51) clear

rename A year
destring _all, replace force
save `NIPA69', replace

/* Read in NIPA data table 2.1 for 1929 - 1969 */
import excel using "${data_dir}/aggregate_data/NIPA21.xlsx", sheet("NIPA 1929") firstrow cellra(A2:AU43) clear

rename A year
destring _all, replace force
drop if year == 1969
save `NIPA29', replace

/* Read in NIPA table 3.12 data 1929 - 2017 */
import excel using "${data_dir}/aggregate_data/NIPA312.xlsx", sheet("table312T") firstrow cellra(A1:AR90) clear

rename A year
destring _all, replace force
save `NIPA312', replace

/* Read in NIPA table 1.12 data 1929 - 2017 */
import excel using "${data_dir}/aggregate_data/NIPA112.xlsx", sheet("table112T") firstrow cellra(A2:AZ91) clear

rename A year
destring _all, replace force
save `NIPA112', replace

/* Read in NIPA table 7.11 data 1929 - 2017 */
import excel using "${data_dir}/aggregate_data/NIPA711.xlsx", sheet("table711T") firstrow cellra(A2:DI74) clear

rename A year
destring _all, replace force
save `NIPA711', replace

/* Read in NIPA table 7.9 data 1929 - 2017 */
import excel using "${data_dir}/aggregate_data/NIPA79.xlsx", sheet("table79T") firstrow cellra(A2:Q74) clear

rename A year
destring _all, replace force
save `NIPA79', replace

/* Read in NIPA table 7.10 data 1929 - 2017 */
import excel using "${data_dir}/aggregate_data/NIPA710.xlsx", sheet("table710T") firstrow cellra(A2:S74) clear

rename A year
destring _all, replace force
save `NIPA710', replace

/* Read in number of households 1940 - 2018 */
import excel using "${data_dir}/aggregate_data/NIPA21.xlsx", sheet("households") firstrow cellra(A1:B80) clear

destring _all, replace force
save `households', replace

/* Combine data */
clear
use `NIPA29', clear
append using `NIPA69'
merge 1:1 year using `NIPA312'
drop _merge
merge 1:1 year using `NIPA112'
drop _merge
merge 1:1 year using `NIPA711'
drop _merge
merge 1:1 year using `NIPA79'
drop _merge
merge 1:1 year using `NIPA710'
drop _merge
merge 1:1 year using `households'
drop _merge
merge 1:1 year using "${data_dir}/CPI_PCE.dta" 
drop _merge

/*
egen NIPAtinc = rowtotal( ///
	Wagesandsalaries ///
	Proprietorsincomewithinven ///
	Rentalincomeofpersonswith ///
	Personalincomereceiptsonas ///
	Socialsecurity2 Unemploymentinsurance Veteransbenefits  ///
	LessContributionsforgovern ///
	)
	*/

gen NIPAtinc = Personalincome + LessContributionsforgovern

egen subtractions21 = rowtotal (  ///
	Supplementstowagesandsal Medicare3 Medicaid  ///
	Other Othercurrenttransferrecei ///
	)	

egen subtractions312 = rowtotal (  ///
	Pensionbenefitguar Militarymedicalins ///
	Blacklungbenefits Other7 Othermedicalca ///
	)	
	
egen subtractions112 = rowtotal (  ///
	Capitalconsumption Inventoryvaluation AN ///
	Capitalconsumptionadju ///
	)	
	
egen subtractions711 = rowtotal (  ///
	Householdsandnonprofit Soleproprietorships  ///
	)		
	
egen subtractions79 = rowtotal (  ///
	Householdsandnonprofitinstitu  ///
	)	
	
egen subtractions710 = rowtotal (  ///
	Imputeddividendsreceivedbype  ///
	)	
	
/* Table 7.20 only provides data back to 1984 */	
replace NIPAtinc = NIPAtinc - subtractions21 - subtractions312 - subtractions112 - subtractions79 - subtractions710	

/* Divide by households and adjust for CPI */
replace NIPAtinc = NIPAtinc/households * 1000000 / CPI

keep if inrange(year,1950,2016)

save "${sav_dir}/NIPA.dta" , replace

use "${data_dir}/SCF_plus.dta", clear

collapse tinc [aw = wgtI95W95], by(yearmerge)

rename yearmerge year

rename tinc SCFtinc

merge 1:1 year using "${sav_dir}/NIPA.dta"
drop _merge

foreach ds in "SCF" "NIPA" {
	foreach pi in "tinc" {
		quietly : sum `ds'`pi' if inlist(year,1983,1989)
		gen `ds'`pi'_I = `ds'`pi'/`r(mean)' * 100
		}
	}

sort year

twoway ///
connected  SCFtinc_I year, msize(large) mcolor(gs0) || ///
line NIPAtinc_I year, lpattern("--") lwidth(thick) lcolor(blue)/*
*/ legend(bplacement(nw) ring(0) col(1) order(2 1) symxsize(8) lab(1 "SCF+") lab(2 "NIPA")) xscale(r(1950 2014)) xlabel(1950(10)2014) xtitle("") /*
*/ yscale(r(40 150)) ylabel(40(10)150) ytitle("") /*
*/ name("TINC_indexed", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) 
graph export "${sav_dir}/SCF_NIPA_income_indexed.eps", replace

*-------------------------------------------------------------------------------
* SCF and Flow of Funds comparison 
*-------------------------------------------------------------------------------
clear
set more off

/* Load SCF data */
use "${data_dir}/SCF_plus.dta", clear

/* Remove SCF components as described in Appendix B of Dettling et al. (2015) */
gen SCFnw = ffanw - life - ofin - vehi - onfin + othdebt
gen SCFfin = ffafin - life - ofin
gen SCFnfin = ffanfin - vehi - onfin
gen SCFhouse = house
gen SCFbus   = ffabus
gen SCFtdebt = tdebt - othdebt
gen SCFpdebt = pdebt - othdebt
gen SCFhdebt = hdebt

/* Construct wealth measures upstream rather than downstream */
replace SCFnfin = house + ffabus
replace SCFnw = SCFnfin + SCFfin - SCFtdebt

collapse SCF* [aw = wgtI95W95], by(yearmerge)

/* Construction from FA data
NW = FIN + NFIN - TDEBT

FIN   = DEPOS + BONDS + CORPEQUITY + MFUND + DCPEN
NFIN  = BUS + HOUSE
TDEBT = HDEBT + PDEBT

DEPOS       = LM153091003(A) + FL153020005(A) + FL153030005(A) + FL153034005(A)
BONDS       = FL153061105(A) + FL153061705(A) + FL153062005(A) + FL153063005(A)
CORPEQUITY  = LM153064105(A)
MFUND       = LM153064205(A)
DCPEN       = FL574090055(A) + FL224090055(A) + FL344090025(A)  

Pension in defined contribution plans
FL574090055(A) from table L.118
FL224090055(A) from table L.120
FL344090025(A) from table L.119c

BUS   = LM152090205(A)
HOUSE = LM155035015(A)

HDEBT = FL153165105(A)
PDEBT = FL153166000(A)
*/

merge 1:1 year using "${data_dir}/aggregate_data/FFA.dta" 
drop _merge

//tabstat NWratio if NWratio < . , by(yearmerge)
foreach pi in "nw" "fin" "nfin" "tdebt" "hdebt" "pdebt" "house" "bus" {
	tabstat SCF`pi' FFA`pi' if inlist(year,1983,1989)
	}

foreach ds in "SCF" "FFA" {
	foreach pi in "nw" "fin" "nfin" "tdebt" "hdebt" "pdebt" "house" "bus" {
		quietly : sum `ds'`pi' if inlist(year,1983,1989)
		gen `ds'`pi'_I = `ds'`pi'/`r(mean)' * 100
		}
	}

sort year
/* Wealth */
twoway connected  SCFnw_I year , msize(large) mcolor(gs0)  || line FFAnw_I year, lpattern("--") lwidth(thick) lcolor(blue) /*
*/ legend(bplacement(nw) ring(0) col(1) order(2 1) symxsize(8) lab(1 "SCF+") lab(2 "FA")) xscale(r(1950 2014)) xlabel(1950(10)2014) xtitle("") /*
*/ yscale(r(40 265)) ylabel(50(25)250) ytitle("") /*
*/ name("NW_indexed", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) 
graph export "${sav_dir}/SCF_FFA_netwealth_indexed_ffaadjusted.eps", replace

/* Financial assets */
twoway connected  SCFfin_I year , msize(large) mcolor(gs0)  || line FFAfin_I year , lpattern("--") lwidth(thick) lcolor(blue)  /*
*/ legend(bplacement(nw) ring(0) col(1) order(2 1) symxsize(8) lab(1 "SCF+") lab(2 "FA")) xscale(r(1950 2014)) xlabel(1950(10)2014) xtitle("") /*
*/ yscale(r(20 355)) ylabel(50(50)350) ytitle("") /*
*/ name("FIN_indexed", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) 
graph export "${sav_dir}/SCF_FFA_financial_indexed_ffaadjusted.eps", replace

/* Houses */
twoway connected SCFhouse_I year , msize(large) mcolor(gs0) || line FFAhouse_I year  , lpattern("--") lwidth(thick) lcolor(blue)  /*
*/ legend(bplacement(nw) ring(0) col(1) order(2 1) symxsize(8) lab(1 "SCF+") lab(2 "FA")) xscale(r(1950 2014)) xlabel(1950(10)2014) xtitle("") /*
*/ yscale(r(20 240)) ylabel(25(25)225) ytitle("") /*
*/ name("HOUSE_indexed", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) 
graph export "${sav_dir}/SCF_FFA_house_indexed_ffaadjusted.eps", replace

/* Total debt */
twoway connected  SCFtdebt_I year , msize(large) mcolor(gs0) || line FFAtdebt_I year, lpattern("--") lwidth(thick) lcolor(blue)  /*
*/ legend(bplacement(nw) ring(0) col(1) order(2 1) symxsize(8) lab(1 "SCF+") lab(2 "FA")) xscale(r(1950 2014)) xlabel(1950(10)2014) xtitle("") /*
*/ yscale(r(0 290)) ylabel(25(50)275) ytitle("") /*
*/ name("TDEBT_indexed", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) 
graph export "${sav_dir}/SCF_FFA_totaldebt_indexed.eps", replace

/* Housing debt */
twoway connected  SCFhdebt_I year , msize(large) mcolor(gs0) || line FFAhdebt_I year, lpattern("--") lwidth(thick) lcolor(blue)  /*
*/ legend(bplacement(nw) ring(0) col(1) order(2 1) symxsize(8) lab(1 "SCF+") lab(2 "FA")) xscale(r(1950 2014)) xlabel(1950(10)2014) xtitle("") /*
*/ yscale(r(0 310)) ylabel(50(50)300) ytitle("") /*
*/ name("HDEBT_indexed", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) 
graph export "${sav_dir}/SCF_FFA_housingdebt_indexed.eps", replace

********************************************************************************
* Tables 3 + E.5
********************************************************************************

qui use year* id impnum ffanw tinc *groups wgtI95W95 using ${data_dir}/SCF_plus.dta, clear
		
qui levelsof yearmerge, clean local(myears)

	foreach dvar in tinc ffanw { 

		foreach myear of local myears {
		
		di "`myear'"
		
		* compute percentiles
		qui _pctile `dvar' if yearmerge == `myear' [aw=wgtI95W95], p(99)

		local P99 = `r(r1)'

		qui replace `dvar'groups = 4 if yearmerge == `myear' & `dvar' > `P99' & `dvar' < .

		} // myear
	
	} // dvar

	foreach dvar in tinc ffanw { 
	
	qui gen gini_`dvar' = .
	qui gen gini_`dvar'_B99 = .
	qui gen gini_`dvar'_B90 = .

		foreach myear of local myears {
		
		di "`myear'"

		* Ginis
		qui sgini `dvar' [aw=wgtI95W95] if yearmerge == `myear'
		qui replace gini_`dvar' = r(coeff) if yearmerge == `myear'
		
		qui sgini `dvar' [aw=wgtI95W95] if yearmerge == `myear' & `dvar'groups < 4
		qui replace gini_`dvar'_B99 = r(coeff) if yearmerge == `myear'
		
		qui sgini `dvar' [aw=wgtI95W95] if yearmerge == `myear' & `dvar'groups < 3
		qui replace gini_`dvar'_B90 = r(coeff) if yearmerge == `myear'

		} // myear
	
	} // dvar
	
collapse gini*, by(yearmerge)

	foreach var of varlist gini* {
	replace `var' = round(`var' * 100)
	}
	
export excel _all using "${sav_dir}/ginis_all_B99_B90.xlsx", firstrow (var) replace

********************************************************************************
* Figures 4 + 5 + B.8
********************************************************************************
clear all
set more off

local ci_bounds = "5 95"

global num_draws = 999 //number of draws
global historic_bootstrap_years "1949/1951 1953/1960 1962/1963 1965 1967/1971 1977 1983"
global merged_bootstrap_years "1950(3)1971 1977 1983 1989(3)2016"

	foreach myear of numlist $merged_bootstrap_years { 

	di "`myear'"
	
	qui use year* id impnum ffanw tinc if impnum == 1 & yearmerge == `myear' using ${data_dir}/SCF_plus.dta, clear
	merge 1:1 yearmerge id impnum using ${data_dir}/replicate_weights/replicate_weights_`myear'.dta, nogen	
	
		foreach n of numlist 1/$num_draws {
		
		di "`n'"
		
		* new groups	
		global pctls = "50 90 95 99"
		
		qui gen top10_tincshares`n' = .
		qui gen top10_ffanwshares`n' = .
		qui gen top5_tincshares`n' = .
		qui gen top5_ffanwshares`n' = .
		qui gen top1_tincshares`n' = .
		qui gen top1_ffanwshares`n' = .	

			foreach dvar in tinc ffanw { 
			
			qui gen gini_`dvar'`n' = .			
			
			* compute percentiles
			qui _pctile `dvar' [aw = wgtI95W95_imp1_`n'], p($pctls)
			
			local P50 = `r(r1)'
			local P90 = `r(r2)'
			local P95 = `r(r3)'
			local P99 = `r(r4)'
			
			qui sum `dvar' [aw = wgtI95W95_imp1_`n']
			local sumtot_`dvar' = r(sum) // total income or wealth in this year
			
			qui sum `dvar' if `dvar' > `P90' [aw = wgtI95W95_imp1_`n']
			qui replace top10_`dvar'shares`n' = r(sum)/`sumtot_`dvar'' 
			
			qui sum `dvar' if `dvar' > `P95' [aw = wgtI95W95_imp1_`n']
			qui replace top5_`dvar'shares`n' = r(sum)/`sumtot_`dvar'' 
			
			qui sum `dvar' if `dvar' > `P99' [aw = wgtI95W95_imp1_`n']
			qui replace top1_`dvar'shares`n' = r(sum)/`sumtot_`dvar''
			
			* Ginis
			qui sgini `dvar' [aw = wgtI95W95_imp1_`n']
			qui replace gini_`dvar'`n' = r(coeff)
			
			} // dvar

		} // n
		
	qui keep *shares* gini_* yearmerge
	qui keep if _n == 1 // constant within year
	mi unset, asis
	local ci_vars = "top10_tincshares top5_tincshares top1_tincshares top10_ffanwshares top5_ffanwshares top1_ffanwshares gini_tinc gini_ffanw"
	reshape long `ci_vars', i(yearmerge) j(draw)
	
		foreach ci_var of local ci_vars {	
		qui _pctile `ci_var', p(`ci_bounds')	
		qui gen `ci_var'_lb = `r(r1)'
		qui gen `ci_var'_ub = `r(r2)'
		}
		
	qui keep year* *_lb *_ub
	qui keep if _n == 1
		
	if `myear' == 1950 {
	qui save ${sav_dir}/CIs.dta, replace
	}
	else if `myear' > 1950 {
	qui append using ${sav_dir}/CIs.dta
	qui save ${sav_dir}/CIs.dta, replace
	}
		
	} // myear	
	
*** Compute statistics with baseline weights ***
	
qui use year* id impnum ffanw tinc wgtI95W95 using ${data_dir}/SCF_plus.dta, clear
		
* new groups	
global pctls = "50 90 95 99"

qui gen top10_tincshares = .
qui gen top10_ffanwshares = .
qui gen top5_tincshares = .
qui gen top5_ffanwshares = .
qui gen top1_tincshares = .
qui gen top1_ffanwshares = .	

qui levelsof yearmerge, clean local(myears)

	foreach dvar in tinc ffanw { 
	
	qui gen gini_`dvar' = .

		foreach myear of local myears {
		
		di "`myear'"
		
		* compute percentiles
		qui _pctile `dvar' if yearmerge == `myear' [aw=wgtI95W95], p($pctls)
		
		local P50 = `r(r1)'
		local P90 = `r(r2)'
		local P95 = `r(r3)'
		local P99 = `r(r4)'

		qui sum `dvar' if yearmerge == `myear' [aw=wgtI95W95]
		local sumtot_`dvar' = r(sum) // total income or wealth in this year
		
		qui sum `dvar' if yearmerge == `myear' & `dvar' > `P90' [aw=wgtI95W95]
		qui replace top10_`dvar'shares = r(sum)/`sumtot_`dvar'' if yearmerge == `myear'
		
		qui sum `dvar' if yearmerge == `myear' & `dvar' > `P95' [aw=wgtI95W95]
		qui replace top5_`dvar'shares = r(sum)/`sumtot_`dvar'' if yearmerge == `myear'
		
		qui sum `dvar' if yearmerge == `myear' & `dvar' > `P99' [aw=wgtI95W95]
		qui replace top1_`dvar'shares = r(sum)/`sumtot_`dvar'' if yearmerge == `myear'
		
		* Ginis
		qui sgini `dvar' [aw=wgtI95W95] if yearmerge == `myear'
		qui replace gini_`dvar' = r(coeff) if yearmerge == `myear'

		} // myear
	
	} // dvar

qui collapse *shares* gini_*, by(yearmerge) // summarize	

merge m:1 yearmerge using ${sav_dir}/CIs.dta, nogen

* Gini, ffanw
#delimit;
graph twoway  
(rarea gini_ffanw_lb gini_ffanw_ub year, fcolor(eltblue) lcolor(eltblue) ) 
(connected gini_ffanw yearmerge, mc(blue) msym(O) msize(large) lc(blue) lwidth(thick)),
xscale(r(1950 2016)) xlabel(1950(5)2015, labsize(medium)) xsize(6.5) xtitle("") 
ytitle("",size(medlarge)) ylabel(0.65(0.05)0.95,angle(0) labsize(medium)) legend(off)
graphregion(color(white)) plotregion(margin(zero)) name("gini_ffanw_CIs", replace)
;#delimit cr
graph export "${sav_dir}/gini_ffanw_CIs.eps", replace

* Gini, tinc
#delimit;
graph twoway  
(rarea gini_tinc_lb gini_tinc_ub year, fcolor(eltblue) lcolor(eltblue) ) 
(connected gini_tinc yearmerge, mc(blue) msym(O) msize(large) lc(blue) lwidth(thick)),
xscale(r(1950 2016)) xlabel(1950(5)2015, labsize(medium)) xsize(6.5) xtitle("") 
ytitle("",size(medlarge)) ylabel(0.35(0.05)0.6,angle(0) labsize(medium)) legend(off)
graphregion(color(white)) plotregion(margin(zero)) name("gini_tinc_CIs", replace)
;#delimit cr
graph export "${sav_dir}/gini_tinc_CIs.eps", replace

*** merge Piketty-Saez-Zucman data ***

merge m:1 yearmerge using ${data_dir}/tax_data/Piketty_Saez.dta, nogen
merge m:1 yearmerge using ${data_dir}/tax_data/Saez_Zucman.dta, nogen 

* Top 10 & Top 5, ffanw
#delimit;
graph twoway  
(rarea top10_ffanwshares_lb top10_ffanwshares_ub year, fcolor(eltblue) lcolor(eltblue) ) 
(line Zshare_nw_top10 year if year>=1950 ,lcolor(blue) lwidth(thick) lpattern(--) ) 
(scatter top10_ffanwshares yearmerge if year>=1950, mcolor(blue) msymbol(O) 
msize(large) connect(l) lcolor(blue) lwidth(medium)) 

(rarea top5_ffanwshares_lb top5_ffanwshares_ub year, fcolor(eltblue) lcolor(eltblue) ) 
(line Zshare_nw_top5 year if  year>=1950 ,lcolor(red) lwidth(thick) lpattern(--) ) 
(scatter top5_ffanwshares yearmerge if year>=1950 , mcolor(red) msym(d) 
msize(large) connect(l) lcolor(red) lwidth(medium)) ,

xscale(r(1950 2016)) xlabel(1950(5)2015, labsize(medium)) xsize(6.5) xtitle("") 
ytitle("",size(large)) ylabel(0.4(0.1)0.9,angle(0) labsize(medium))
legend(label(1 "90% CI, SCF+")  label(3 "top 10%, SCF+")  label(6 "top 5%, SCF+") 
label(2 "top 10%, Saez-Zucman") label(5 "top 5%, Saez-Zucman")
pos(6) order (3 2 6 5 1) rows(2) colfirst symxsize(4) size(medium)) graphregion(color(white)) 
plotregion(margin(zero)) name("sharetop_nw_CI_top10_top5", replace)
;#delimit cr
graph export "${sav_dir}/sharetop_nw_CI_top10_top5.eps", replace

* Top 1, ffanw
#delimit;
graph twoway  
(rarea top1_ffanwshares_lb top1_ffanwshares_ub year, fcolor(eltblue) lcolor(eltblue) ) 
(line Zshare_nw_top1 year if year>=1950 ,lcolor(gs0) lwidth(thick) lpattern(--)  ) 
(scatter top1_ffanwshares yearmerge if year>=1950, mcolor(gs0) msymbol(T) msize(large) 
connect(l) lcolor(gs0) lwidth(medium) ),

xscale(r(1950 2016)) xlabel(1950(5)2015, labsize(medium)) xsize(6.5) xtitle("") 
ytitle("",size(large)) ylabel(0(0.1)0.6,angle(0) labsize(medium))
legend(label(1 "90% CI, SCF+") label(3 "top 1%, SCF+") label(2 "top 1%, Saez-Zucman")
pos(6) order(3 2 1) rows(1) symxsize(4) size(medium)) graphregion(color(white)) 
plotregion(margin(zero)) name("sharetop_nw_CI_top1", replace)
;#delimit cr
graph export "${sav_dir}/sharetop_nw_CI_top1.eps", replace

* Top 10 & Top 5, tinc
#delimit;
graph twoway  
(rarea top10_tincshares_lb top10_tincshares_ub year, fcolor(eltblue) lcolor(eltblue) ) 
(line Pshare_tinc_top10 year if year>=1950 ,lcolor(blue) lwidth(thick) lpattern(--) ) 
(scatter top10_tincshares yearmerge if year>=1950, mcolor(blue) msymbol(O) 
msize(large) connect(l) lcolor(blue) lwidth(medium)) 

(rarea top5_tincshares_lb top5_tincshares_ub year, fcolor(eltblue) lcolor(eltblue) ) 
(line Pshare_tinc_top5 year if  year>=1950 ,lcolor(red) lwidth(thick) lpattern(--) ) 
(scatter top5_tincshares yearmerge if year>=1950 , mcolor(red) msym(d) 
msize(large) connect(l) lcolor(red) lwidth(medium)) ,

xscale(r(1950 2016)) xlabel(1950(5)2015, labsize(medium)) xsize(6.5) xtitle("") 
ytitle("",size(large)) ylabel(0(0.1)0.5,angle(0) labsize(medium))
legend(label(1 "90% CI, SCF+")  label(3 "top 10%, SCF+")  label(6 "top 5%, SCF+") 
label(2 "top 10%, Piketty-Saez") label(5 "top 5%, Piketty-Saez")
pos(6) order (3 2 6 5 1) rows(2) colfirst symxsize(4) size(medium)) graphregion(color(white)) 
plotregion(margin(zero)) name("sharetop_tinc_CI_top10_top5", replace)
;#delimit cr
graph export "${sav_dir}/sharetop_tinc_CI_top10_top5.eps", replace

* Top 1, tinc
#delimit;
graph twoway  
(rarea top1_tincshares_lb top1_tincshares_ub year, fcolor(eltblue) lcolor(eltblue) ) 
(line Pshare_tinc_top1 year if year>=1950 ,lcolor(black) lwidth(thick) lpattern(--)  ) 
(scatter top1_tincshares yearmerge if year>=1950, mcolor(black) msymbol(T) msize(large) 
connect(l) lcolor(black) lwidth(medium) ),

xscale(r(1950 2016)) xlabel(1950(5)2015, labsize(medium)) xsize(6.5) xtitle("") 
ytitle("",size(large)) ylabel(0(0.1)0.3,angle(0) labsize(medium))
legend(label(1 "90% CI, SCF+")  label(3 "top 1%, SCF+") label(2 "top 1%, Piketty-Saez")
pos(6) order(3 2 1) rows(1) symxsize(4) size(medium)) graphregion(color(white)) 
plotregion(margin(zero)) name("sharetop_tinc_CI_top1", replace)
;#delimit cr
graph export "${sav_dir}/sharetop_tinc_CI_top1.eps", replace

********************************************************************************
* Table 4
********************************************************************************

qui use ${data_dir}/SCF_plus.dta, clear
mi unset, asis

rename tincgroups incomegroups
rename ffanwgroups wealthgroups

keep if inlist(yearmerge, 1950, 1971, 1989, 2007, 2016)

* shares in income by income groups and wealth by wealth groups
	foreach var in tinc ffanw { 
	
		if "`var'" == "tinc" {
		local vname = "income"
		} // if
		else if "`var'" == "ffanw" {
		local vname = "wealth"
		} // else
	
	preserve

	qui bysort yearmerge: egen double `var'sum = total(`var'*wgtI95W95)
	qui bysort yearmerge `vname'groups: egen double `var'sum_group = total(`var'*wgtI95W95)
	qui gen `var'_share = round(`var'sum_group/`var'sum*100, 0.1)

	qui collapse `var'_share, by(yearmerge `vname'groups) // summarize

	reshape wide `var'_share, i(yearmerge) j(`vname'groups)
	
	label var `var'_share1 "bottom 50%"
	label var `var'_share2 "50 - 90%"
	label var `var'_share3 "top 10%"

	export excel _all using "${sav_dir}/`vname'shares_detailed.xlsx", ///
	firstrow (varl) sheet(by`vname') sheetmodify
	
	restore

	} // var
	
qui use ${data_dir}/SCF_plus.dta, clear
mi unset, asis

drop tincgroups ffanwgroups

global pctls = "25 50 75 90"
qui gen tincgroups = .
qui gen ffanwgroups = .

qui levelsof yearmerge, clean local(myears)

	foreach dvar in tinc ffanw { 

		foreach myear of local myears {
		
		* compute percentiles
		qui _pctile `dvar' if yearmerge == `myear' [aw=wgtI95W95], p($pctls)
		
		local P25 = `r(r1)'
		local P50 = `r(r2)'
		local P75 = `r(r3)'
		local P90 = `r(r4)'
		
		qui replace `dvar'groups = 1 if `dvar' <= `P25' & yearmerge == `myear' 
		qui replace `dvar'groups = 2 if `dvar' > `P25' & `dvar' <= `P50'  & yearmerge == `myear' 
		qui replace `dvar'groups = 3 if `dvar' > `P50' & `dvar' <= `P75'  & yearmerge == `myear' 
		qui replace `dvar'groups = 4 if `dvar' > `P75' & `dvar' <= `P90'  & yearmerge == `myear' 

		} // myear
	
	} // dvar
	
rename tincgroups incomegroups
rename ffanwgroups wealthgroups

keep if inlist(yearmerge, 1950, 1971, 1989, 2007, 2016)

* shares in income by income groups and wealth by wealth groups
	foreach var in tinc ffanw { 
	
		if "`var'" == "tinc" {
		local vname = "income"
		} // if
		else if "`var'" == "ffanw" {
		local vname = "wealth"
		} // else
	
	preserve

	qui bysort yearmerge: egen double `var'sum = total(`var'*wgtI95W95)
	qui bysort yearmerge `vname'groups: egen double `var'sum_group = total(`var'*wgtI95W95)
	qui gen `var'_share = round(`var'sum_group/`var'sum*100, 0.1)

	qui collapse `var'_share, by(yearmerge `vname'groups) // summarize
	
	drop if `vname'groups == .

	reshape wide `var'_share, i(yearmerge) j(`vname'groups)
	
	label var `var'_share1 "bottom 25%"
	label var `var'_share2 "25 - 50%"
	label var `var'_share3 "50 - 75%"
	label var `var'_share4 "75 - 90%"

	export excel `var'_share? using "${sav_dir}/`vname'shares_detailed.xlsx", ///
	firstrow (varl) cell(E1) sheet(by`vname') sheetmodify
	
	restore

	} // var

********************************************************************************
* Figures 6 + 7
********************************************************************************
clear
set more off
set trace off
window manage close graph _all

use "${data_dir}/SCF_plus.dta" , clear
mi unset , asis

/* Statistics of low wealth */
gen netdebtors = (ffanw < 0)
gen wealth3month = (ffanw < tinc * 3/12)
gen debtors = (tdebt > 0)  
gen homeowner = (house > 0 & house < .)

preserve

collapse netdebtors wealth3month debtors [aw = wgtI95W95], by(yearmerge) 

twoway line netdebtors yearmerge , lwidth(thick) lc(blue) || line wealth3month yearmerge , /*
*/ lpattern("--") lwidth(thick) lc(black) name("LowWealth", replace) /*
*/ scheme(s2mono) graphregion(color(white)) bgcolor(white) /*title("Share of low wealth households")*/ /*
*/ xscale(r(1949 2017)) xlabel(1950(5)2015) xtitle("") /*
*/ yscale(r(0.0 0.36)) ylabel(0(0.05)0.35) ytitle("") /*
*/ legend(bplacement(ne) ring(0) col(1)  lab(1 "negative wealth") lab(2 "3-month of income")  ) 
graph export "${sav_dir}/lowwealth.eps", replace
	
restore

preserve

gen negwealth = (ffanw < 0) + (house <= 0) * (ffanw < 0)
label define negwealth 0 "positive wealth" 1 "homeowner w neg. wealth" 2 "neg. wealth no house" , replace 
label values negwealth negwealth

/* Non homeowner negative wealth */

drop if negwealth == 0
recode negwealth (2=0) 
collapse negwealth [aw = wgtI95W95], by(yearmerge)

twoway line negwealth yearmerge ,lpattern("l") lc(blue) lwidth(thick) name("HomeownerLowWealth", replace) /*
*/ scheme(s2mono) graphregion(color(white)) bgcolor(white) /*title("Share of low wealth households")*/ /*
*/ xscale(r(1949 2017)) xlabel(1950(5)2015) xtitle("") /*
*/ yscale(r(0.0 0.42)) ylabel(0(0.1)0.4, format(%4.2f)) ytitle("") legend(off)
graph export "${sav_dir}/lowwealthhomeowner.eps", replace

restore

collapse (p50) p50wealth = ffanw p50income = tinc /*
*/ (p25) p25wealth = ffanw p25income = tinc /*
*/ (p75) p75wealth = ffanw p75income = tinc /*
*/ (p90) p90wealth = ffanw p90income = tinc /*
 */ [aw = wgtI95W95], by(yearmerge) 

 foreach qrat in "5025" "7550" "9050" {
	foreach cvar in "wealth" "income" {
		local fp = substr("`qrat'",1,2)
		local lp = substr("`qrat'",3,2)
		cap drop p`fp'`lp'`cvar'*
		gen p`fp'`lp'`cvar' = p`fp'`cvar'/p`lp'`cvar'
		quietly : sum p`fp'`lp'`cvar' if yearmerge == 1971
		gen p`fp'`lp'`cvar'_I1971 = p`fp'`lp'`cvar'/`r(mean)'		
		}
	}	
 	
twoway ///
line p5025wealth yearmerge , lwidth(thick) lpattern("l") lc(blue) xscale(r(1949 2017)) xlabel(1950(10)2010) xtitle("") || ///
line p7550wealth yearmerge , yaxis(2) lwidth(thick) lpattern("--") lc(red) || ///
line p9050wealth yearmerge , yaxis(1) lwidth(thick) lpattern("_") lc(black) /*
*/  yscale(r(3 12) axis(1)) yscale(r(1 5) axis(2)) ylabel(3(1)12 , axis(1)) ylabel(1(1)5,  axis(2)) /*
*/ scheme(s2mono) graphregion(color(white)) bgcolor(white)  ytitle("", axis(1)) ytitle("", axis(2)) /*
*/ legend(bplacement(nw) ring(0) col(1)  lab(1 "50-25 ratio (left axis)") lab(2 "75-50 ratio (right axis)") lab(3 "90-50 ratio (left axis)")) name("bottomwealth", replace)
graph export "${sav_dir}/QuantileRatiosBottom90wealth.eps", replace

twoway ///
line p5025income yearmerge , lwidth(thick) lpattern("l") lc(blue) xscale(r(1949 2017)) xlabel(1950(10)2010) xtitle("") || ///
line p7550income yearmerge , yaxis(2) lwidth(thick) lpattern("--") lc(red) || ///
line p9050income yearmerge , yaxis(2) lwidth(thick) lpattern("_") lc(black) /*
*/  yscale(r(1 2.5)  axis(1)) yscale(r(1 3.5) axis(2)) ylabel(1(0.5)2.5, axis(1)) ylabel(1(0.5)3.5, axis(2))/*
*/ scheme(s2mono) graphregion(color(white)) bgcolor(white) ytitle("", axis(1)) ytitle("", axis(2)) /*
*/ legend(bplacement(nw) ring(0) col(1)  lab(1 "50-25 ratio (left axis)") lab(2 "75-50 ratio (right axis)") lab(3 "90-50 ratio (right axis)")) name("bottomincome", replace)
graph export "${sav_dir}/QuantileRatiosBottom90income.eps", replace

foreach qt in "25" "50" "75" {
	foreach cvar in "wealth" "income" {
		quietly : sum p`qt'`cvar' if yearmerge == 1971
		gen p`qt'`cvar'_I1971 = p`qt'`cvar'/`r(mean)'	
		local `cvar'level`qt' = `r(mean)'
		local `cvar'level`qt' : display "`qt'th ($" %8.0fc ``cvar'level`qt'' ")"
		}
	}

twoway line p25wealth_I1971 yearmerge , lwidth(thick) lpattern("--") lc(blue) || /*
*/ line p50wealth_I1971 yearmerge , lwidth(thick) lpattern("l") lc(red) || /*
*/ line p75wealth_I1971 yearmerge , lwidth(thick) lpattern("_") lc(black) /*
*/ xscale(r(1949 2017)) xlabel(1950(10)2010) xtitle("") /*
*/ scheme(s2mono) graphregion(color(white)) bgcolor(white) /*
*/ legend(bplacement(nw) ring(0) col(1)  lab(1 "`wealthlevel25'") lab(2 "`wealthlevel50'") lab(3 "`wealthlevel75'")) /*
*/name("wealthPctBottom", replace)		
graph export "${sav_dir}/wealthinequalitybottom90.eps", replace

twoway line p25income_I1971 yearmerge , lwidth(thick) lpattern("--") lc(blue) || /*
*/ line p50income_I1971 yearmerge , lwidth(thick) lpattern("l") lc(red) || /*
*/ line p75income_I1971 yearmerge , lwidth(thick) lpattern("_") lc(black) /*
*/ xscale(r(1949 2017)) xlabel(1950(10)2010) xtitle("") /*
*/ scheme(s2mono) graphregion(color(white)) bgcolor(white) /*
*/ legend(bplacement(nw) ring(0) col(1)  lab(1 "`incomelevel25'") lab(2 "`incomelevel50'") lab(3 "`incomelevel75'")) /*
*/name("incomePctBottom", replace)	
graph export "${sav_dir}/incomeinequalitybottom90.eps", replace

********************************************************************************
* Figures 8 + A.2
********************************************************************************

clear all
set more off

* 1: baseline, 2: alternative cash adjustment, 3: alternative with 5%, 
* 4: alternative with decline from 5% to 2%, 5: estimate from ncvs
* local cash_adj = 1

local sample = "full" // full / homeowners

foreach cash_adj of numlist 1 5 {

	if `cash_adj' == 4 {

	tempfile lin_decline

	qui use ${data_dir}/SCF_plus, clear
	collapse impnum, by(year) // just to get years
	drop impnum

	gen ptrend_aux = 5 if year == 1949
	replace ptrend_aux = 2 if year == 2016
	ipolate ptrend_aux year, gen(ptrend)
	drop *_aux

	save `lin_decline', replace

	} // if
	
	qui use ${data_dir}/SCF_plus.dta, clear
	qui sort year id impnum

	if `cash_adj' == 4 {
	merge m:1 year using `lin_decline', nogen
	} // if
		
// age restriction
keep if ageh >= 22 & ageh <= 79

// drop if negative income
drop if incwsse < 0 | incws < 0 | tinc < 0

// optional: sample selection
	if "`sample'" == "homeowners" {
	drop if house == 0
	}

// drop if only self-employment income
replace incwsse = incws if (incwsse == 0 | incwsse == .) & (incws != 0 & incws != .)
drop if incwsse > 0 & incws == 0

gen paymfreq = 4 // divided by two from equations in paper, and again by two due to bi-weekly payment assumption
global illiqvarlim = 0

*** income ***

* Original Definition:
* labinc = rowtotal(X5702 X5716 X5718 X5720 X5722 X5724 X5726)

qui egen labinc = rowtotal(incwsse inctrans) // rowtotal(incws inctrans)
qui gen inccap_neg = -1*inccap
qui egen tinc_nocap = rowtotal(tinc inccap_neg)

	if `cash_adj' == 5 {

	* compute ratio to ncvs
	
	tempfile ncvs

	preserve

	collapse (median) tinc labinc [aw=wgtI95W95], by(yearmerge)

	gen year = yearmerge
	merge 1:1 year using ${data_dir}/CPI_PCE.dta
	qui drop if _merge == 2
	qui drop _merge

	merge 1:1 year using ${data_dir}/cash_vic.dta, keepus(cash)
	qui drop if _merge == 2
	qui drop _merge

	qui replace cash = cash/CPI // deflate

	qui gen cash_tinc = cash/(tinc/12)*100

	* twoway line cash_tinc year if inrange(year, 1983,2004) || line cash_labinc year if inrange(year, 1983,2004)

	reg cash_tinc year
	predict est_cash_frac_ncvs_lin, xb 

	twoway line cash_tinc year, lc(blue) lwidth(medthick) || ///
	line est_cash_frac_ncvs_lin year, lc(gs0) lp(dash) ///
	plotregion(color(white)) graphregion(color(white)) bgcolor(white) ///
	xlabel(1950(5)2016) yscale(r(0 10)) ylabel(0(2)10, angle(0)) ///
	legend(off) ytitle("") xtitle("") name("est_cash", replace)
	graph export "${sav_dir}/est_cash_`sample'.eps", replace

	save `ncvs', replace

	restore

	} // if

*qui replace prepaid = 0

*** liquid assets ***

* Original Definition:
* ccdebt = rowtotal(X413 X421 X424 X427 X430)
* liqvar = liq*(1+138/2500) + nmmf + stocks + bond - ccdebt, 
* liq = checking + saving + mmda + call + mmmf + prepaid

qui gen ccdebt_neg = -1*ccdebt

	if `cash_adj' == 1 {
	qui gen cashfrac = 138/2500 // average cash holdings excluding large value holdings divided by median liquid assets in 2010, following KVW (2014)
	qui egen liq_adj = rowtotal(liq moneymarketacc prepaid) // note: liquid_c = chsavacc + callmmacc = checking + saving + mmda + call
	qui replace liq_adj = liq_adj*(1+cashfrac) // adjusted by cash holdings
	} // if
	
	else if `cash_adj' == 2 {
	qui gen cash = 1/6*tinc/100
	qui egen liq_adj = rowtotal(liq moneymarketacc prepaid cash) // note: liquid_c = chsavacc + callmmacc = checking + saving + mmda + call
	} // else
	
	else if `cash_adj' == 3 {
	qui gen cash = 5/12*tinc/100
	qui egen liq_adj = rowtotal(liq moneymarketacc prepaid cash) // note: liquid_c = chsavacc + callmmacc = checking + saving + mmda + call
	} // else
	
	else if `cash_adj' == 4 {
	qui gen cash = ptrend/12*tinc/100
	qui egen liq_adj = rowtotal(liq moneymarketacc prepaid cash) // note: liquid_c = chsavacc + callmmacc = checking + saving + mmda + call
	} // else
	
	else if `cash_adj' == 5 {
	merge m:1 yearmerge using `ncvs', nogen keepus(est_cash_frac_ncvs_lin) // est_cash_frac_ncvs_epol
	qui gen cash = est_cash_frac_ncvs_lin/12*tinc/100
	qui egen liq_adj = rowtotal(liq moneymarketacc prepaid cash) // note: liquid_c = chsavacc + callmmacc = checking + saving + mmda + call
	} // else
	
qui gen savbnd_neg = -1*savbnd
* note: bnd = bond + savbnd
qui egen liqvar = rowtotal(liq_adj mfun ffaequ bnd savbnd_neg ccdebt_neg)

*** illiquid assets ***

* Original Definition:
* illiqvar = houses + oresre + nnresre + cds + retqliq + cashli + savbnd - mrthel – resdbt

qui gen hdebt_neg = -1*hdebt
qui gen oestdebt_neg = -1*oestdebt
qui egen illiqvar = rowtotal(house oest cerde pen life savbnd hdebt_neg oestdebt_neg)

	foreach incvar in labinc { // tinc_nocap tinc labinc

	preserve

	qui gen monthinc = `incvar'/12 // monthly income
	qui gen m = 1*monthinc // 1 month borrowing limit

	gen htm0_a = 0
	gen htm0_b =0

	* (8) and (10)
	replace htm0_a = 1 if (liqvar >= 0 & liqvar <= monthinc/paymfreq) | ///
	(liqvar < 0 & liqvar <= (monthinc/paymfreq - m) )

	* (9) and (11)
	replace htm0_b = 1 if (liqvar >= 0 & liqvar <= monthinc/paymfreq & illiqvar > ${illiqvarlim}) | ///
	(liqvar < 0 & liqvar <= (monthinc/paymfreq - m) & illiqvar > ${illiqvarlim})

	//Generate hand to mouth characterizations
	gen h2m = (htm0_a == 1) // hand-to-mouth
	gen Wh2m = (htm0_b == 1) // wealthy hand-to-mouth
	gen Ph2m = (htm0_a == 1 & htm0_b == 0) // poor hand-to-mouth
	gen Nh2m = (htm0_a == 0)
	
	* exclude 1967 and 1977, because liquid assets are imputed
	qui replace Wh2m = . if inlist(year, 1967, 1977)
	qui replace Ph2m = . if inlist(year, 1967, 1977)
	
	*qui savesome h2m Wh2m Ph2m year id impnum using "${data_dir}/HtM_`cash_adj'.dta", replace
	
	// collapses means over year and imputation
	collapse (mean) h2m Wh2m Ph2m Nh2m [aw=wgtI95W95], by(yearmerge)
	
	export excel using "${sav_dir}/HtM_HSCF_`incvar'_`cash_adj'_`sample'.xlsx", replace
	
	drop if yearmerge == 1977

	graph bar Wh2m Ph2m, over(year, gap(*0.6) label(angle(45)) ) stack ///
	bar(1, color(red*0.8) lc(black)) bar(2, color(blue) lc(black)) ///
	plotregion(color(white)) graphregion(color(white)) bgcolor(white) ///
	legend(label(1 "wealthy HtM") label(2 "poor HtM")) ysc(r(0 0.4)) ///
	ylabel(0(0.1)0.4) ytitle("") name("HtM_HSCF_`incvar'_`cash_adj'_`sample'", replace)
	graph export "${sav_dir}/HtM_HSCF_`incvar'_`cash_adj'_`sample'.eps", replace
	
	restore

	} // incvar

cd "${sav_dir}"
!del interim*

} // cash_adj

********************************************************************************
* Figure 9
********************************************************************************

clear all
set more off
set scheme s2mono

*-------------------------------------------------------------------------------
* Adjust for OECD scale
*-------------------------------------------------------------------------------
	
qui use ${data_dir}/SCF_plus.dta, clear

qui gen ffanw_oecd = ffanw/hhequiv
qui gen tinc_oecd = tinc/hhequiv
	
qui levelsof yearmerge, clean local(myears)

	foreach gvar in ffanw ffanw_oecd tinc tinc_oecd {
	
	qui gen gini_`gvar' = .

		foreach myear of local myears {

		sgini `gvar' [aw=wgtI95W95] if yearmerge == `myear'
		qui replace gini_`gvar' = r(coeff) if yearmerge == `myear'

		} //	
		
	} // gvar	
	
qui collapse gini_*, by(yearmerge) // summarize

	foreach gvar in ffanw tinc {	
	
	if "`gvar'" == "ffanw" {
	local ylab = "0.65(0.05)0.90"
	}
	else if "`gvar'" == "tinc" {
	local ylab = "0.35(0.05)0.6"
	}
	
	twoway ///
	connected gini_`gvar' yearmerge, lc(gs0) msym(o) msize(medlarge) mfc(gs0) mlc(gs0) || ///
	connected gini_`gvar'_oecd yearmerge, lc(blue) msym(s) msize(medium) mfc(blue) mlc(blue) ///
	plotregion(color(white)) graphregion(color(white)) bgcolor(white) ytitle("") xtitle("") ///
	legend( lab(1 "observed") lab(2 "OECD equivalence scale")) ///
	xlabel(1950(5)2015, angle(45)) ylabel(`ylab', angle(0)) name("gini_`gvar'_oecd", replace)
	graph export "${sav_dir}/gini_`gvar'_oecd.eps", replace	
		
	} // gvar	
	
*-------------------------------------------------------------------------------
* Adjust for demographics (following Fortin et al.)
*-------------------------------------------------------------------------------
	
local years_surveys  "1950(3)1971 1977 1983 1989(3)2016"
local baseyear = 1971

	foreach myear of numlist `years_surveys'{

	di "`baseyear' `myear'"

	qui use if yearmerge==`baseyear' | yearmerge==`myear' using ${data_dir}/SCF_plus.dta, clear

	qui replace adults = . if adults == 0
	qui replace agehgroup = . if agehgroup == 0

	qui gen age_var = agehgroup
	qui gen edu_var = collegeh
	qui gen adu_var = adults 
	qui gen chi_var = children 
	qui gen rac_var = blackh

	* Construct re-weighting factors
	local reg_vars "i.age_var i.edu_var i.adu_var i.chi_var i.rac_var"

		if `myear'~=`baseyear' {
		
		qui gen yearmerge_`baseyear' = (yearmerge == `baseyear')

		*Sample proportions of each group:
		qui egen pop = total(wgtI95W95)
		qui bysort yearmerge: egen pop_bygroup = total(wgtI95W95) 

		qui gen aux = pop_bygroup/pop if yearmerge==`baseyear'
		qui egen S`baseyear' = mean(aux)
		qui drop aux
		qui gen aux = pop_bygroup/pop if yearmerge==`myear'
		qui egen S`myear' = mean(aux)
		qui drop aux

		* All covariates:
		estimates clear 
		ereturn clear
		qui glm yearmerge_`baseyear' `reg_vars' [aw=wgtI95W95] if yearmerge==`baseyear' | yearmerge==`myear', family(binomial) link(probit) diff iterate(20)
		qui predict prob_`baseyear' if yearmerge==`baseyear' | yearmerge==`myear'
		qui gen prob_`myear' = 1-prob_`baseyear'

		qui gen phi_all = (prob_`baseyear'/S`baseyear') / (prob_`myear'/S`myear')
		
		qui gen wgtI95W95_adj_all = wgtI95W95 * phi_all

		qui drop prob_`baseyear' prob_`myear'

			* Exclude each subvar:
			foreach subX in age edu {

			local vars_subX = subinstr("`reg_vars'","i.`subX'_var","",.)
			
			qui gen wgtI95W95_adj_`subX' = .

			estimates clear
			ereturn clear
			qui glm yearmerge_`baseyear'  `vars_subX' [aw=wgtI95W95] if yearmerge==`baseyear' | yearmerge==`myear', family(binomial) link(probit) diff iterate(20)
			qui predict prob_`baseyear' if yearmerge==`baseyear' | yearmerge==`myear'
			qui gen prob_`myear' = 1-prob_`baseyear'

			qui gen phi_ex_`subX' = (prob_`baseyear'/S`baseyear') / (prob_`myear'/S`myear')
			qui gen phi_rat_ex_`subX' = phi_all/phi_ex_`subX'

			qui drop prob_`baseyear' prob_`myear'

			qui replace wgtI95W95_adj_`subX' = wgtI95W95*phi_rat_ex_`subX' if yearmerge==`myear'

			} //subX

		qui keep if yearmerge == `myear'
		qui keep year id impnum wgtI95W95_adj_*
		
		qui save ${sav_dir}/interim_weights_`myear', replace

		} // `myear'~=`baseyear'
		
		else if `myear'==`baseyear' {
		
		qui gen wgtI95W95_adj_all = wgtI95W95
		qui gen wgtI95W95_adj_edu = wgtI95W95
		qui gen wgtI95W95_adj_age = wgtI95W95
		
		qui keep if yearmerge == `myear'
		qui keep year id impnum wgtI95W95_adj_*
		
		qui save ${sav_dir}/interim_weights_`myear', replace
		
		} // else
		
	} // myear
	
clear

	foreach myear of numlist 1950(3)1971 1977 1983 1989(3)2016 {
	qui append using ${sav_dir}/interim_weights_`myear'.dta
	} // myear
	
qui save ${sav_dir}/adjusted_weights_demographics, replace
	
cd ${sav_dir}
!del interim*

merge 1:1 year id impnum using ${data_dir}/SCF_plus.dta, nogen

qui levelsof yearmerge, clean local(myears)

	foreach gvar in ffanw tinc {	
	
		foreach wgt_ver in "" "_adj_all" "_adj_age" "_adj_edu" {
		
		qui gen gini_`gvar'`wgt_ver' = .
		
			foreach myear of local myears {
			sgini `gvar' [aw=wgtI95W95`wgt_ver'] if yearmerge == `myear'
			qui replace gini_`gvar'`wgt_ver' = r(coeff) if yearmerge == `myear'
			} //		
			
		} // wgt_ver	
		
	} // gvar
	
qui collapse gini_*, by(yearmerge) // summarize

	foreach gvar in ffanw tinc {	
	
		if "`gvar'" == "ffanw" {
		local ylab = "0.65(0.05)0.9"
		}
		else if "`gvar'" == "tinc" {
		local ylab = "0.35(0.05)0.6"
		}
		
	qui gen marginal_`gvar'_edu = gini_`gvar'_adj_edu - gini_`gvar'_adj_all
	qui gen marginal_`gvar'_age = gini_`gvar'_adj_age - gini_`gvar'_adj_all
	
	qui gen gini_`gvar'_base_marginal_edu = gini_`gvar' + marginal_`gvar'_edu
	qui gen gini_`gvar'_base_marginal_age = gini_`gvar' + marginal_`gvar'_age
	
	twoway ///
	connected gini_`gvar' yearmerge, lc(gs0) msym(o) msize(medlarge) mfc(gs0) mlc(gs0) || ///
	connected gini_`gvar'_base_marginal_age yearmerge, lc(blue) msym(s) msize(medium) mfc(blue) mlc(blue) || ///
	connected gini_`gvar'_base_marginal_edu yearmerge, lc(red) msym(d) msize(medium) mfc(red) mlc(red) ///	
	plotregion(color(white)) graphregion(color(white)) bgcolor(white) ytitle("") xtitle("") ///
	legend( lab(1 "observed") lab(2 "age of 1971") lab(3 "education of 1971") row(1) symxsize(7) ) ///
	xlabel(1950(5)2015, angle(45)) ylabel(`ylab', angle(0)) name("gini_`gvar'_demo_base_plus_marg", replace)
	graph export "${sav_dir}/gini_`gvar'_demo_base_plus_marg.eps", replace	
		
	} // gvar	
	
********************************************************************************
* Figures 10 + 11
********************************************************************************
clear
set more off

global tholds = "p50 p90"

qui use "${data_dir}/SCF_plus.dta", clear
mi unset, asis

/* Generate black-white dummy and drop "other" race */
qui drop if raceh == 0
qui gen black = (raceh == 1)

qui label define  blackwhite 1 "black" 0 "white"
qui label values black blackwhite

qui drop year
qui rename yearmerge year 

/* Mean ratios excluding top 5% of the (unconditional) wealth distribution */
foreach si in 3 4 { // 1(1)4 {

	/*
	si = 1 : full sample, mean
	si = 2 : no top 10%, mean
	si = 3 : full sample, median
	si = 4 : full sample, p90
	*/

	preserve
	
	if(`si' == 1) {
		collapse (mean) ffanw tinc [aw = wgtI95W95], by(year black)
		local samplestr = ""
		local statstr = "mean"
		}
	else if(`si' == 2){
		collapse (mean) ffanw tinc if ffanw <= p90wealth [aw = wgtI95W95], by(year black)
		local samplestr = "_notop10wealth"
		local statstr = "mean"
		}
	else if(`si' == 3){
		collapse (p50) ffanw tinc [aw = wgtI95W95], by(year black)
		local samplestr = ""
		local statstr = "p50"
		}
	else if(`si' == 4){
		collapse (p90) ffanw tinc [aw = wgtI95W95], by(year black)
		local samplestr = ""
		local statstr = "p90"
		}
		
	qui reshape wide ffanw tinc , i(year) j(black)

	gen wealthratio = ffanw0/ffanw1
	gen incomeratio = tinc0/tinc1

	forvalues i = 0(1)1 { // relative to average in 1980s
	
		qui gen ffanw`i'_MA = .
		qui gen tinc`i'_MA = .		
		
			foreach yy of numlist 2/`=_N-1' {
		
			qui sum ffanw`i' if inrange(year, year[`yy'-1], year[`yy'+1]) 
			qui replace ffanw`i'_MA = r(mean) if year == year[`yy']
			qui sum tinc`i' if inrange(year,year[`yy'-1], year[`yy'+1]) 
			qui replace tinc`i'_MA = r(mean) if year == year[`yy']
			
			} // yy	
			
			foreach yy of numlist `=_N'/`=_N' { // last available wave
		
			qui sum ffanw`i' if inrange(year, year[`yy'-1], year[`yy']) 
			qui replace ffanw`i'_MA = r(mean) if year == year[`yy']
			qui sum tinc`i' if inrange(year,year[`yy'-1], year[`yy']) 
			qui replace tinc`i'_MA = r(mean) if year == year[`yy']
			
			} // yy	
	
		qui sum ffanw`i' if inrange(year,1980,1989) 
		local wealth_level`i' = `r(mean)'
		qui gen ffanw`i'_orig = ffanw`i'
		qui replace ffanw`i' = ffanw`i'/`wealth_level`i'' * 100

		qui sum ffanw`i'_MA if inrange(year,1980,1989) 
		local wealth_level`i'_MA = `r(mean)'
		qui gen ffanw`i'_MA_orig = ffanw`i'_MA
		qui replace ffanw`i'_MA = ffanw`i'_MA/`wealth_level`i'_MA' * 100
		
		qui sum tinc`i' if inrange(year,1980,1989) 
		local income_level`i' = `r(mean)'
		qui gen tinc`i'_orig = tinc`i'
		qui replace tinc`i' = tinc`i'/`income_level`i'' * 100
		
		qui sum tinc`i'_MA if inrange(year,1980,1989) 
		local income_level`i'_MA = `r(mean)'
		qui gen tinc`i'_MA_orig = tinc`i'_MA
		qui replace tinc`i'_MA = tinc`i'_MA/`income_level`i'_MA' * 100
		
		} // i
		
	local versions = "_MA" // `" "" "_MA" "' // within year vs. 3-year MA
		
		foreach version of local versions {
		
			* local to display averages in legend
			if `si' < 4 {
			local wealth_level0`version' : display %7.0fc `wealth_level0`version''
			local wealth_level1`version' : display %8.0fc `wealth_level1`version''
			local income_level0`version' : display %6.0fc `income_level0`version''
			local income_level1`version' : display %6.0fc `income_level1`version''
			}
			else if `si' == 4 {
			local wealth_level0`version' : display %7.0fc `wealth_level0`version''
			local wealth_level1`version' : display %7.0fc `wealth_level1`version''
			local income_level0`version' : display %7.0fc `income_level0`version''
			local income_level1`version' : display %8.0fc `income_level1`version'' 
			}
		
		* generate meanwealthgrowth_blackwhite, p90wealthgrowth_blackwhite
		twoway ///
		connected ffanw0`version' year , msize(large) msymbol(S) mfc(gs16) mlc(gs0) || connected ffanw1`version' year , msize(vlarge) mc(black) msymbol(O) /*
		*/ xscale(r(1949 2017)) xlabel(1950(10)2015, labsize(medlarge)) xtitle("")  /*
		*/ legend(bplacement(nw) ring(0) col(1) lab(1 "white ($ `wealth_level0`version'')") lab(2 "black ($ `wealth_level1`version'')")) /*
		*/ scheme(s2mono) graphregion(color(white)) bgcolor(white) name("D`statstr'Wealth`si'`version'", replace)
		graph export "${sav_dir}/`statstr'wealthgrowth_blackwhite`samplestr'`version'`HHadj'.eps", replace 
		
		* generate meanincomegrowth_blackwhite, p90incomegrowth_blackwhite
		twoway ///
		connected tinc0`version' year , msize(large) msymbol(S) mfc(gs16) mlc(gs0) || connected tinc1`version' year , msize(vlarge) mc(black) msymbol(O) /*
		*/  xscale(r(1949 2017)) xlabel(1950(10)2015, labsize(medlarge)) xtitle("")  /*
		*/ legend(bplacement(nw) ring(0) col(1) lab(1 "white ($ `income_level0`version'')") lab(2 "black ($ `income_level1`version'')")) /*
		*/ scheme(s2mono) graphregion(color(white)) bgcolor(white) name("D`statstr'Income`si'`version'", replace)
		graph export "${sav_dir}/`statstr'incomegrowth_blackwhite`samplestr'`version'`HHadj'.eps", replace 
		
		} // version

	restore
	
	} // si	

tempfile pctblack	

preserve
/* Percentiles of the black wealth distribution */
keep if black == 1
*gen femalehead = 
collapse (p50) p50wealth = ffanw (p90) p90wealth = ffanw [aw = wgtI95W95] , by(year)
save `pctblack' , replace
restore

preserve
/* Locate percentiles in the white wealth distribution */
keep if black == 0
merge m:1 year using `pctblack', nogen

gen locp50 = (ffanw < p50wealth) * wgtI95W95
gen locp90 = (ffanw < p90wealth) * wgtI95W95

collapse (sum) locp50 locp90 wgtI95W95 , by(year)

/* Rank gap : Bayer and Charles */ 
replace locp50 = 100 * (locp50/wgtI95W95 - 0.5)
replace locp90 = 100 * (locp90/wgtI95W95 - 0.9)

sort year

quietly sum locp50
gen meanp50 = r(mean)

quietly sum locp90
gen meanp90 = r(mean)

/* Rank gap */
line locp50 year , lwidth(thick) lc(blue) || line meanp50 year  , lwidth(thick) xscale(r(1950 2016)) xlabel(1950(10)2010, labsize(medlarge)) xticks(1950(10)2010) /*
*/ yscale(r(-40 0)) yticks(-35(5)-5) ylabel(-35(5)-5, labsize(medlarge)) xtitle("") name("locationmedian", replace) /*
*/  scheme(s2mono) graphregion(color(white)) bgcolor(white) legend(off)
graph export "${sav_dir}/blacklocationmedian`HHadj'.eps" , logo(off) replace 

line locp90 year , lwidth(thick) lc(blue) || lfit meanp90 year , lwidth(thick)  xscale(r(1950 2016)) xlabel(1950(10)2010, labsize(medlarge)) xticks(1950(10)2010) /*
*/ yscale(r(-40 0)) yticks(-35(5)-5) ylabel(-35(5)-5, labsize(medlarge)) xtitle("") name("locationp90", replace) /*
*/  scheme(s2mono) graphregion(color(white)) bgcolor(white) legend(off)
graph export "${sav_dir}/blacklocationp90`HHadj'.eps" , logo(off) replace 

********************************************************************************
* Figures 12 + 13
********************************************************************************
qui use "${data_dir}/SCF_plus.dta", clear

qui gen ffanw_PCE = ffanw * CPI / PCE
qui gen tinc_PCE = tinc * CPI / PCE

* by wealth
qui collapse ffanw tinc ffanw_PCE tinc_PCE [aw=wgtI95W95], by(yearmerge ffanwgroups)

qui gen wti = ffanw/tinc
qui gen ffanw_rel = .
qui gen tinc_rel = .
qui gen ffanw_PCE_rel = .
qui gen tinc_PCE_rel = .
qui gen wti_rel = .

	foreach j of numlist 1/3 {
	
		foreach var in ffanw tinc ffanw_PCE tinc_PCE wti {

		qui sum `var' if yearmerge == 1971 & ffanwgroups == `j'
		qui replace `var'_rel = `var'/`r(mean)' if ffanwgroups == `j'
		
		} // var

	} // j
	
	foreach var in ffanw tinc ffanw_PCE tinc_PCE {
	
	if "`var'" == "tinc" {
	local ys_gr = "0 2.5"
	local ylab_gr = "0(0.5)2.5"
	local gname = "incomegrowth_bywealthgroup_BY1971"
	}
	else if  "`var'" == "tinc_PCE" {
	local ys_gr = "0 3"
	local ylab_gr = "0(0.5)3"
	local gname = "incomegrowth_bywealthgroup_BY1971_PCE"
	}
	else if "`var'" == "ffanw" {
	local ys_gr = "0 3"
	local ylab_gr = "0(0.5)3"
	local gname = "wealthgrowth_bywealthgroup_BY1971"
	}
	else if "`var'" == "ffanw_PCE" {
	local ys_gr = "0 3.5"
	local ylab_gr = "0(0.5)3.5"
	local gname = "wealthgrowth_bywealthgroup_BY1971_PCE"
	}

	twoway line `var'_rel year if ffanwgroups == 1, lc(gs0) lp(solid) lwidth(thick) || ///
	line `var'_rel year if ffanwgroups == 2, lc(blue) lp(shortdash) lwidth(thick) || ///
	line `var'_rel year if ffanwgroups == 3, lc(red) lp(longdash) lwidth(thick) ///
	xline(2007, lc(black) lp(shortdash)) ///
	yscale(r(`ys_gr')) ylabel(`ylab_gr') xscale(r(1950 2016)) xlabel(1950(5)2015) ///
	legend(row(1) lab(1 "0% - 50%") lab(2 "50% - 90%") lab(3 "Top 10%")) ///
	graphregion(color(white)) bgcolor(white) xtitle("") ytitle("") name("`var'_growth_nw", replace)
	graph export "${sav_dir}/`gname'.eps", replace

	} // var

twoway line wti year if ffanwgroups == 1, lc(gs0) lp(solid) lwidth(thick) || ///
line wti year if ffanwgroups == 2, yaxis(2) lc(blue) lp(shortdash) lwidth(thick) ///
yscale(r(0.2 0.8) axis(1)) ylabel(0.2(0.1)0.8, axis(1)) ///
yscale(r(2 5.5) axis(2)) ylabel(2(0.5)5.5, axis(2)) xscale(r(1950 2016)) xlabel(1950(5)2015) ///
legend(bplacement(nw) ring(0) row(2) lab(1 "0% - 50% (left axis)") lab(2 "50% - 90% (right axis)")) ///
graphregion(color(white)) bgcolor(white) xtitle("") ytitle("") ytitle("", axis(2)) name("W2Ybottom", replace)
graph export "${sav_dir}/W2Ybottom.eps", replace

twoway line wti year if ffanwgroups == 3, lc(red) lp(longdash) lwidth(thick) ///
yscale(r(7 15)) ylabel(7(1)15) xscale(r(1950 2016)) xlabel(1950(5)2015) ///
legend(on bplacement(nw) ring(0) row(1) lab(1 "Top 10%")) ///
graphregion(color(white)) bgcolor(white) xtitle("") ytitle("") name("W2Ytop", replace)
graph export "${sav_dir}/W2Ytop.eps", replace

********************************************************************************
* Figure 14
********************************************************************************
qui use "${data_dir}/SCF_plus.dta", clear

/* Use flow of funds adjusted data */
rename ffabus bus
rename ffaequ equ
rename ffaass ass
rename ffanfin nfin
rename ffafin fin
rename ffanw nw

/* Aggregated portfolio positions */
gen liqbnd = liqcer + bnd 
gen otherfin = ofin + pen + life 
replace equ = equ + mfun
gen busiw = bus 
gen othernonfin	= vehi + onfin + oest

collapse othernonfin house busiw equ liqbnd otherfin pdebt hdebt [aw = wgtI95W95], by(yearmerge)

gen assets = othernonfin + house + busiw + equ + liqbnd  + otherfin 
gen debt = pdebt + hdebt
gen wealth = (assets - debt)/10000

gen assetstack1 = otherfin/10000
gen assetstack2 = assetstack1 + liqbnd /10000
gen assetstack3 = assetstack2 + equ/10000
gen assetstack4 = assetstack3 + busiw /10000 
gen assetstack5 = assetstack4 + house/10000
gen assetstack6 = assetstack5 + othernonfin/10000

gen debtstack1 = -hdebt/10000
gen debtstack2 = debtstack1 - pdebt/10000

foreach avar of varlist othernonfin house busiw equ liqbnd otherfin {
	quietly : replace `avar'  = round(`avar'/assets * 100,0.1)
	}

foreach dvar of varlist pdebt hdebt {
	quietly : replace `dvar'  = round(`dvar'/debt * 100,0.1)
	}

drop if yearmerge >= .

colorpalette webcolors_blue, nograph
twoway area assetstack6 year, color(eltblue) lcolor(gs0) /*
*/ /*|| area assetstack5 year, color(gs13) lcolor(gs0)*/ /*
*/ || area assetstack4 year, color(blue) lcolor(gs0) /*
*/ /*|| area assetstack3 year, color(gs9) lcolor(gs0)*/ /*
*/ || area assetstack2 year, color(navy) lcolor(gs0) /*
*/ /*|| area assetstack1 year, color(gs5) lcolor(gs0)*/ /*
*/ || area debtstack2 year, color(ebblue) lcolor(gs0) /*
*/ || area debtstack1 year,  color(eltblue) lcolor(gs0) /*
*/ || line wealth year, lc(red) lwidth(vthick) lpattern(--) /*
*/ legend(ring(0) cols(2) colfirst holes(8) position(11) size(small) /*
*/ symysize(3) symxsize(4) rowgap(1) order(- "{it:Assets:}"1 2 3 - "{it:Debt:}" 5 4) /*
*/ lab(1 "housing + non-fin. assets") lab(2 "stocks + business") /*
*/ lab(3 "bonds + liquid and oth. fin. assets ") lab(4 "non-housing debt") lab(5 "housing debt") ) /*
*/ yscale(r(-15 105)) ylabel(-20(20)100) xtitle("") ytitle("x 10,000") /*
*/ xscale(r(1950 2016)) xlabel(1950(10)2010) graphregion(color(white)) bgcolor(white) name("portfoliocomposition", replace)
graph export "${sav_dir}/portfolio_allhouseholds_newgroups.eps", replace	

*-------------------------------------------------------------------------------
* by groups
*-------------------------------------------------------------------------------

qui use "${data_dir}/SCF_plus.dta", clear

/* Use flow of funds adjusted data */
rename ffabus bus
rename ffaequ equ
rename ffaass ass
rename ffanfin nfin
rename ffafin fin
rename ffanw nw

/* Aggregated portfolio positions */
gen liqbnd = liqcer + bnd 
gen otherfin = ofin + pen + life 
replace equ = equ + mfun
gen busiw = bus 
gen othernonfin	= vehi + onfin + oest

collapse othernonfin house busiw equ liqbnd otherfin pdebt hdebt [aw = wgtI95W95], by(yearmerge ffanwgroups)

gen assets = othernonfin + house + busiw + equ + liqbnd  + otherfin
gen debt = pdebt + hdebt
gen daratio = round(debt/assets * 100,0.1)
gen wealth = (assets - debt)/10000

	foreach var in otherfin liqbnd equ busiw house othernonfin {
	qui gen sh_`var' = round(`var'/assets*100,0.1)
	} // var
	
	foreach var in pdebt hdebt {
	qui gen sh_`var' = round(`var'/debt*100,0.1)
	} // var
	
********************************************************************************
* Tables E.6 - E.8
********************************************************************************	

	foreach j of numlist 1/3 {
	qui export excel yearmerge sh_othernonfin sh_house sh_busiw sh_equ sh_liqbnd sh_otherfin ///
	sh_pdebt sh_hdebt daratio if ffanwgroups == `j' using ///
	"${sav_dir}/portfolioshares_group`j'.xlsx", firstrow(var) replace
	} // j

gen assetstack1 = otherfin/10000
gen assetstack2 = assetstack1 + liqbnd /10000
gen assetstack3 = assetstack2 + equ/10000
gen assetstack4 = assetstack3 + busiw /10000 
gen assetstack5 = assetstack4 + house/10000
gen assetstack6 = assetstack5 + othernonfin/10000

gen debtstack1 = -hdebt/10000
gen debtstack2 = debtstack1 - pdebt/10000

drop if yearmerge >= .

	foreach group of numlist 1/3 {
	
		if `group' == 1 {		
		local yrange = "-6 14"	
		local ylabrange = "-6(2)14"
		}
		else if `group' == 2 {		
		local yrange = "-10 60"	
		local ylabrange = "-10(5)60"
		}
		else if `group' == 3 {		
		local yrange = "-40 560"	
		local ylabrange = "0(80)560"
		}

	twoway area assetstack6 year if ffanwgroups == `group', color(eltblue) lcolor(gs0) /*
	*/ /*|| area assetstack5 year if ffanwgroups == `group', color(gs13) lcolor(gs0)*/ /*
	*/ || area assetstack4 year if ffanwgroups == `group', color(blue) lcolor(gs0) /*
	*/ /*|| area assetstack3 year if ffanwgroups == `group', color(gs9) lcolor(gs0)*/ /*
	*/ || area assetstack2 year if ffanwgroups == `group', color(navy) lcolor(gs0) /*
	*/ /*|| area assetstack1 year if ffanwgroups == `group', color(gs5) lcolor(gs0)*/ /*
	*/ || area debtstack2 year  if ffanwgroups == `group', color(ebblue) lcolor(gs0) /*
	*/ || area debtstack1 year  if ffanwgroups == `group',  color(eltblue) lcolor(gs0) /*
	*/ || line wealth year if ffanwgroups == `group', lc(red) lwidth(vthick) lpattern(--) /*
	*/ legend(ring(0) cols(2) colfirst holes(8) position(11) size(small) /*
	*/ symysize(3) symxsize(4) rowgap(1) order(- "{it:Assets:}"1 2 3 - "{it:Debt:}" 5 4) /*
	*/ lab(1 "housing + non-fin. assets") lab(2 "stocks + business") /*
	*/ lab(3 "bonds + liquid and oth. fin. assets ") lab(4 "non-housing debt") lab(5 "housing debt") ) /*
	*/ yscale(r(`yrange')) ylabel(`ylabrange') xtitle("") ytitle("x 10,000") /*
	*/ xscale(r(1950 2016)) xlabel(1950(10)2010) graphregion(color(white)) bgcolor(white) name("portfoliocomposition`group'", replace)	
	graph export "${sav_dir}/portfolio_group`group'_newgroups.eps", replace	
	
	} // group

********************************************************************************
* Figure 15
********************************************************************************
qui use "${data_dir}/SCF_plus.dta", clear
mi unset, asis

gen equ = ffaequ + mfun

bysort yearmerge: egen house_total = total(house*wgtI95W95)
bysort yearmerge ffanwgroups: egen house_groups = total(house*wgtI95W95)
qui gen house_share = house_groups / house_total * 100

bysort yearmerge: egen equ_total = total(equ*wgtI95W95)
bysort yearmerge ffanwgroups: egen equ_groups = total(equ*wgtI95W95)
qui gen equ_share = equ_groups / equ_total * 100

collapse equ_share house_share, by(yearmerge ffanwgroups) // summarize

rename (house_share equ_share) (ac1 ac2)
reshape long ac, i(yearmerge ffanwgroups) j(assetclass)
label def asset_lab 1 "housing" 2 "stocks", replace
label val assetclass asset_lab
reshape wide ac, i(yearmerge assetclass) j(ffanwgroups)	

foreach cyear of numlist 1950 1971 2007 { 

	graph hbar ac1 ac2 ac3 if year == `cyear', over(assetclass, label(labsize(vlarge))) ///
	stack bar(1, color(gs16) lc(gs0) lwidth(medthick)) bar(2, color(blue) lc(gs0) ///
	lwidth(medthick)) bar(3, color(red*0.8) lc(gs0) lwidth(medthick)) ///
	legend(lab(3 "top 10%") lab(2 "50% - 90%") lab(1 "bottom 50%") row(1)) graphregion(color(white)) ///
	bgcolor(white) ytitle("") title("`cyear'", size(huge)) name("assetdistribution_`cyear'", replace) nodraw
	}
	
grc1leg assetdistribution_1950 assetdistribution_1971 assetdistribution_2007, ///
rows(1) graphregion(color(white)) xsize(4) ysize(3) ///
name("assetdistribution_all", replace) position (6)
graph display, xsize(3) ysize(1)
graph export "${sav_dir}/assetdistribution_all.eps", replace

********************************************************************************
* Figure 16
********************************************************************************
qui use "${data_dir}/SCF_plus.dta", clear

replace house = house

collapse house ffanw [aw=wgtI95W95], by(yearmerge ffanwgroups)

gen hpe = house/ffanw * 100

twoway ///
connected hpe yearmerge if ffanwgroups == 2, lc(blue) msym(o) msize(large) mfc(blue) mlc(blue) || ///
connected hpe yearmerge if ffanwgroups == 3, msym(s) msize(large) mfc(red) lc(red) mlc(red) ///
legend(lab(1 "50-90%") lab(2 "Top 10%") ) ///
title("") plotregion(color(white)) graphregion(color(white)) bgcolor(white) ///
xlabel(1950(5)2015) xtitle("") ytitle("percent") name("exposure", replace) 
graph export "${sav_dir}/exposure_middleclass_houseRffanw_ffanw_2.eps", replace

********************************************************************************
* Figure 17 + Table 5
********************************************************************************
use "${data_dir}/SCF_plus.dta" , clear	
mi unset , asis

replace house = house
replace ffaequ = ffaequ + mfun

tempfile thresholds
preserve
collapse (p90) p90wealth = ffanw (mean) meanincome = tinc (mean) meanwealth = ffanw /*
*/ (mean) meanhouse = house (mean) meanstocks = ffaequ [aw = wgtI95W95], by(yearmerge)
save `thresholds' , replace
restore

merge m:1 yearmerge using `thresholds'
drop _merge

keep if ffanw > p90wealth

collapse (mean) p90wealth = ffanw  (mean) p90income = tinc (mean) meanincome = meanincome (mean) meanwealth = meanwealth /*
*/ (mean) house = house (mean) stocks = ffaequ (mean) meanhouse = meanhouse (mean) meanstocks = meanstocks [aw = wgtI95W95], by(yearmerge)

gen top10wealthshare = p90wealth/meanwealth * 0.1 
gen top10incomeshare = p90income/meanincome * 0.1 

gen p90stockshare = stocks/p90wealth
gen p90houseshare = house/p90wealth

gen stockshare = meanstocks/meanwealth
gen houseshare = meanhouse/meanwealth

rename yearmerge year

merge m:1 year using "${data_dir}/assetprices.dta"	
keep if _merge == 3
drop _merge	

sort year

egen timeline = seq()
gen timeline2 = timeline*timeline
tsset timeline

gen wealthgrowth = F.meanwealth/meanwealth
gen Y2W = meanincome/meanwealth
gen p90Y2W = p90income/p90wealth

gen stockgrowth = log(F.stockprice/stockprice)  
label var stockgrowth "stock price growth"
gen housegrowth = log(F.houseprice/houseprice) 
label var housegrowth "house price growth"
gen top10growth = log(F.top10wealthshare/top10wealthshare) 
label var top10growth "growth top 10% wealth share"

gen incineq = top10incomeshare
	
estimates clear

quietly: regress top10growth stockgrowth housegrowth 
estimates store race_baseline

quietly: regress top10growth stockgrowth housegrowth incineq
estimates store race_ineq

quietly: regress top10growth stockgrowth housegrowth Y2W 
estimates store race_Y2W
	
quietly: regress top10growth stockgrowth housegrowth incineq Y2W
estimates store race_ineq_Y2W

estimates table * , star(0.2 0.1 0.05) stats(N r2) keep(housegrowth stockgrowth ) b(%7.3f) 

esttab race_baseline race_ineq race_Y2W race_ineq_Y2W /*
*/ using "${sav_dir}/raceregression.tex" , not ar2 label  obslast nomtitles nonumbers   replace b(%7.4f) /*
*/ stats(N r2, labels("N" "R^2") fmt(%4.0f %4.2f)) star(* 0.2 ** 0.1 *** 0.05) keep(housegrowth stockgrowth) order(housegrowth stockgrowth)  /*
*/ prefoot("\hline \theta^{top10} & no & yes & no & yes \\ \frac{Y}{W} & no & no & yes & yes \\ \hline") 

gen housepriceelasticity = 1/(wealthgrowth) * (p90houseshare - F.top10wealthshare/top10wealthshare * houseshare) 
gen stockpriceelasticity = 1/(wealthgrowth) * (p90stockshare - F.top10wealthshare/top10wealthshare * stockshare) 

estimates restore race_ineq_Y2W

gen housepriceelasticityhat = _b[housegrowth] 
gen stockpriceelasticityhat = _b[stockgrowth]  

* tabstat housepriceelasticity stockpriceelasticity housepriceelasticityhat stockpriceelasticityhat, s(mean)

line housepriceelasticity year , lwidth(thick) lpattern(solid) lc(blue) || ///
line stockpriceelasticity year, lwidth(thick) lpattern(--) lc(red) /*
*/ legend(ring(0) cols(1) bplacement(ne) lab(1 "house price") lab(2 "stock price")) /*
*/ xscale(r(1950 2016)) xlabel(1950(5)2016) xtitle("") ///
graphregion(color(white)) bgcolor(white) name("assetpriceelasticities", replace)
graph export "${sav_dir}/assetpriceelasticities.eps", replace

********************************************************************************
* Figures 18 + 19 + Table 6
********************************************************************************
	
qui use "${data_dir}/SCF_plus.dta" , clear	
mi unset , asis

replace house = house
replace ffaequ = ffaequ + mfun

qui gen deposits = liqcer + bnd

foreach baseyear of numlist 1971 2007 { 

	preserve

	qui collapse wealth=ffanw income=tinc house equity=ffaequ [aw = wgtI95W95], by(yearmerge ffanwgroups)

	qui rename yearmerge year

	merge m:1 year using "${data_dir}/assetprices.dta"	
	qui drop if _merge == 2
	qui drop _merge	

	qui sum ffanwgroups
	local nwg = `r(max)' // number of ffanwgroups

	rename stockprice equityprice

		foreach vvar in wealth income { 
		
		qui gen `vvar'`baseyear' = .
			
			forvalues i = 1(1)`nwg' {
			qui sum `vvar' if year == `baseyear' & ffanwgroups == `i'
			replace `vvar'`baseyear' = `r(mean)' if ffanwgroups == `i'
			} // i
			
		gen `vvar'growth = `vvar' - `vvar'`baseyear'

		} // vvar
			
		foreach vvar in "house" "equity" {
		
		qui gen `vvar'`baseyear' = .
		
			forvalues i = 1(1)`nwg' {
			qui sum `vvar' if year == `baseyear' & ffanwgroups == `i'
			replace `vvar'`baseyear' = `r(mean)' if ffanwgroups == `i'
			} // i

		qui sum `vvar'price if year == `baseyear'
		qui gen `vvar'price`baseyear' = `r(mean)'	
		qui gen `vvar'pricegain = `vvar'`baseyear' * (`vvar'price/`vvar'price`baseyear' - 1)					
		qui gen share`vvar'pricegain = `vvar'pricegain/wealth`baseyear'
		
		gen `vvar'pricegrowthshare = `vvar'pricegain/wealthgrowth
		
		} // vvar

		if `baseyear' == 1971 {
		numlist "2007"
		local ymin = 0
		local ymax = 1
		local ystep = 0.1
		}
		else if `baseyear' == 2007 {
		numlist "2016"
		local ymin = -0.2
		local ymax = 0.05
		local ystep = 0.05
		}

	local cyearlist = "`r(numlist)'"
		
		foreach cyear of numlist `cyearlist' {		

		graph bar sharehousepricegain shareequitypricegain if year == `cyear', ///
		graphregion(color(white)) bgcolor(white) legend(lab(1 "house price") lab(2 "stock price")) ///
		over(ffanwgroups) stack bar(1, color(red*0.8)) bar(2, color(blue)) ///		
		yscale(r(`ymin' `ymax')) ytick(`ymin'(`ystep')`ymax') ylabel(`ymin'(`ystep')`ymax')  name("priceeffect`baseyear'", replace)
		graph export "${sav_dir}/importancepriceeffect_`baseyear'`cyear'_plusmfun.eps", replace
		
		graph bar housepricegrowthshare equitypricegrowthshare if year == `cyear', ///
		graphregion(color(white)) bgcolor(white) legend(lab(1 "house price") lab(2 "stock price")) ///
		over(ffanwgroups) stack bar(1, color(red*0.8)) bar(2, color(blue)) ///		
		yscale(r(`ymin' `ymax')) ytick(`ymin'(`ystep')`ymax') ylabel(`ymin'(`ystep')`ymax')  name("share_priceeffect`baseyear'", replace)
		graph export "${sav_dir}/sharegrowthpriceeffects_`baseyear'`cyear'_plusmfun.eps", replace

		} // cyear
		
		if `baseyear' == 1971 {	
		
		gen wealth_nohp = wealth - housepricegain
		gen wealth_noep = wealth - equitypricegain
		
		keep year wealth_nohp wealth_noep wealth ffanwgroups
		
		reshape wide wealth_nohp wealth_noep wealth, i(year) j(ffanwgroups)

			foreach vvar in wealth_nohp wealth_noep wealth {
			gen `vvar'_share1 = 0.5 * `vvar'1/(`vvar'1 * 0.5 + `vvar'2 * 0.4 + `vvar'3 * 0.1)
			gen `vvar'_share2 = 0.4 * `vvar'2/(`vvar'1 * 0.5 + `vvar'2 * 0.4 + `vvar'3 * 0.1)
			gen `vvar'_share3 = 0.1 * `vvar'3/(`vvar'1 * 0.5 + `vvar'2 * 0.4 + `vvar'3 * 0.1)
			}

		keep if inlist(year, 1971, 1989, 2007, 2016)
			
			foreach var of varlist *_share? {
			qui sum `var' if year == 1971
			qui gen rel_`var' = round((`var' - `r(mean)')*100, 0.1)
			}
			
		keep year rel_*
		keep if year > 1971
		
		reshape long rel_wealth_nohp_share rel_wealth_noep_share rel_wealth_share, i(year) j(ffanwgroups)
		order year ffanwgroups rel_wealth_share rel_wealth_nohp_share rel_wealth_noep_share
		sort ffanwgroups year

		export excel year *share* using "${sav_dir}/wealthshares_counterfactual.xlsx", firstrow(variables) replace  				
		
		} // if
			
	restore
		
	} // baseyear
	
********************************************************************************
* Figures B.3 - B.6
********************************************************************************

clear
set more off
window manage close graph _all

tempfile taxpercentiles taxlevels taxunits wealththres pensionshare

/* Top 0.1% share */
use "${data_dir}/SCF_plus.dta", clear

numlist "1950(3)1971 1977 1983 1989(3)2016"
local SCFyears = "`r(numlist)'"

foreach cyear in `SCFyears' {
	_pctile ffanw if yearmerge == `cyear' [aw = wgtI95W95 ], p(99.9)
	local p999 = `r(r1)'
	quietly : sum ffanw if yearmerge == `cyear' [aw = wgtI95W95 ]
	local meanwealth = `r(mean)'
	quietly : sum ffanw if yearmerge == `cyear' & ffanw >= `p999' [aw = wgtI95W95 ]
	local meantop = `r(mean)'
	local topshare = round(`meantop'/`meanwealth' * 1/1000,0.001) * 100
	display "`cyear' : " %6.1f " `topshare' %"
	}

*-------------------------------------------------------------------------------
* Perform Top 1% test from BPEA for income using Piketty/Saez data 
*-------------------------------------------------------------------------------
import excel using "${data_dir}/tax_data/Piketty_Saez.xls" , sheet("Table A4") cellrange(A41:R107) clear

keep A P Q R D

rename A year 
rename P p90tax
rename Q p95tax
rename R p99tax 
rename D mean99tax 

/* Adjust from 2014 to 2016 dollars */
replace p90tax = p90tax * 352.6/347.8
replace p95tax = p95tax * 352.6/347.8
replace p99tax = p99tax * 352.6/347.8
replace mean99tax = mean99tax * 352.6/347.8

save `taxpercentiles', replace

import excel using "${data_dir}/tax_data/Piketty_Saez.xls" , sheet("Table A0") cellrange(A41:B107) clear

rename A year 
rename B TaxUnits

save `taxunits', replace

use "${data_dir}/SCF_plus.dta", clear

merge m:1 year using `taxpercentiles'

/* Tax data ends 2014 */
keep if _merge == 3
drop _merge

merge m:1 year using `taxunits'

/* Tax data ends 2014 */
keep if _merge == 3
drop _merge

/* Share of households above percentiles of the income distribution from tax data */
gen share90 = (tinc > p90tax)
gen share95 = (tinc > p95tax)
gen share99 = (tinc > p99tax)

//gen unitratio = TaxUnits/Households

preserve
collapse share9* /*unitratio*/ [aw = wgtI95W95], by(yearmerge)

rename yearmerge year
merge 1:1 year using `taxpercentiles'
drop _merge
sort year

foreach pct in "90" "95" "99" {
	egen meanshare`pct' = mean(share`pct') 
	}
	
twoway connected share99 year , lwidth(thick) msize(vlarge) mlc(red) mfc(red) lc(red) || /*
	*/ line meanshare99 year, lpattern("--") lwidth(thick) /*
	*/ name("incomeshare99", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) xscale(r(1950 2014)) xlabel(1950(10)2014) xtitle("") /*
	*/ xlabel(,labsize(medlarge)) ylabel(,labsize(medlarge)) yscale(r(0 0.045)) ylabel(0.0(0.01)0.04) ytitle("")  legend(off)
graph export "${sav_dir}/incomeshare99.eps" , replace

twoway connected share90 year , lwidth(thick) msize(vlarge) mlc(blue) mfc(blue) lc(blue) || /*
	*/ line meanshare90 year, lpattern("--") lwidth(thick) || /*
	*/ connected share95 year , lwidth(thick) msize(large) mlc(ebblue) mfc(ebblue) lc(ebblue) || /*
	*/ line meanshare95 year, lpattern("--") lwidth(thick) /*
	*/ name("incomeshare9095", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) xscale(r(1950 2014)) xlabel(1950(10)2014) xtitle("") /*
	*/ xlabel(,labsize(medlarge)) ylabel(,labsize(medlarge)) yscale(r(0 0.22)) ylabel(0.0(0.05)0.2) ytitle("") /*
	*/ legend(order(1 3) col(1) bplacement(sw) ring(0) lab(1 "share HH over 90th pct") lab(3 "share HH over 95th pct"))	
graph export "${sav_dir}/incomeshare9095.eps" , replace
	
restore

/* Average income for households above the 99th percentile from the tax data */
preserve
keep if share99 == 1
collapse tinc [aw = wgtI95W95 ], by(yearmerge)

rename yearmerge year
merge 1:1 year using `taxpercentiles'
drop _merge
sort year

replace tinc = tinc/100000
replace mean99tax = mean99tax/100000

twoway connected tinc year , lwidth(thick) msize(vlarge) mlc(gs0) mfc(gs0) || line mean99tax year, lc(blue) lpattern("--") lwidth(thick) /*
	*/ name("incomeleveltop1", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) xscale(r(1950 2014)) xlabel(1950(10)2014) xtitle("") ytitle("x 100,000", size(medlarge)) /*
	*/ yscale(r(0 11.5)) ylabel(0(2)10) /*
	*/ xlabel(,labsize(medlarge)) ylabel(,labsize(medlarge)) legend(bplacement(nw) ring(0)  lab(1 "SCF+") lab(2 "Tax data"))
graph export "${sav_dir}/incomeleveltop1.eps" , replace

restore

*-------------------------------------------------------------------------------
* Perfrom Top 1% test from BPEA for wealth using Saez/Zucman data 
*-------------------------------------------------------------------------------
import excel using "${data_dir}/tax_data/Top1Thresholds.xlsx", sheet("Pensions") cellrange(A2:AD64) clear

rename A year
rename I psharebottom90
rename P psharetop10
rename W psharetop5
rename AD psharetop1 

keep year pshare* 

save `pensionshare' , replace

/* Load percentile data */
import excel using "${data_dir}/tax_data/Top1Thresholds.xlsx", sheet("WealthThresholds") cellrange(A3:H65) clear

rename A year
rename E p99KS
rename F p90SZ
rename G p95SZ
rename H p99SZ

merge 1:1 year using "${data_dir}/CPI_PCE.dta" 
keep if year >= 1950 & year <= 2012
drop _merge

merge 1:1 year using `pensionshare' 

/* CPI adjust to current 2016 dollars */
foreach cvar in "p99KS" "p90SZ" "p95SZ" "p99SZ" {
	quietly : replace `cvar' = `cvar'/CPI 
	}

drop _merge CPI

/* Adjust for pension share */
replace p90SZ  = p90SZ * (1 - psharetop10)
replace p95SZ  = p95SZ * (1 - psharetop5)
replace p99SZ  = p99SZ * (1 - psharetop1)

gen yearmerge = year
	
save `taxpercentiles', replace

/* Get percentiles from SCF data */
use "${data_dir}/SCF_plus.dta", clear

/* Make wealth data comparable by subtracting pensions */
gen ffanwno = ffanw - pen

preserve
collapse (p90) p90wealth = ffanwno (p95) p95wealth = ffanwno (p99) p99wealth = ffanwno (mean) meanadults = adults [aw= wgtI95W95], by(yearmerge)

save `wealththres' , replace
restore

/* Start with SCF micro data */
/* Merge in percentiles from tax data */
merge m:1 yearmerge using `taxpercentiles'
drop _merge

/* Merge SCF and tax data percentiles */
merge m:1 yearmerge using `wealththres'
drop _merge

sort year
replace meanadults = meanadults[_n-1] if meanadults >= .
replace meanadults = meanadults[_n+1] if meanadults >= .
replace meanadults = meanadults[_n-2] if meanadults >= .
replace meanadults = meanadults[_n+2] if meanadults >= .

/* Kopczuk-Saez data individuals (age 20+) not households/tax units (use SCF number of adults to adjust to household level) */
replace p99KS = p99KS * meanadults

gen share90 = (ffanwno >= p90SZ)
gen share95 = (ffanwno >= p95SZ)
gen share99 = (ffanwno >= p99SZ)
//replace share99 = (ffanw >= p99KS) if p99SZ >= .

preserve
collapse share9* p9* [aw = wgtI95W95 ], by(yearmerge)

rename yearmerge year
merge 1:1 year using `taxpercentiles'
drop _merge
sort year

foreach pct in "90" "95" "99" {
	quietly : sum share`pct' if share`pct' > 0 & yearmerge < 2000
	gen meanshare`pct' = `r(mean)' 
	quietly : sum share`pct' if share`pct' > 0 
	gen mean2share`pct' = `r(mean)' 
	}

twoway connected share99 year if inrange(year,1962,2012), lwidth(thick) msize(vlarge) mlc(red) mfc(red) lc(red) || /*
	*/ line mean2share99 year if inrange(year,1962,2012), lpattern("--") lwidth(thick) /*
	*/   name("wealthshare99", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) xscale(r(1962 2012)) xlabel(1960(10)2012) xtitle("") /*
	*/ xlabel(,labsize(medlarge)) ylabel(,labsize(medlarge)) yscale(r(0 0.035)) ylabel(0.0(0.01)0.03) ytitle("")  legend(off)
	graph export "${sav_dir}/wealthshare99.eps" , replace
	
twoway connected share90 year if inrange(year,1962,2012), lwidth(thick) msize(vlarge) mlc(blue) mfc(blue) lc(blue) || /*
	*/ line mean2share90 year if inrange(year,1962,2012), lpattern("--") lwidth(thick) || /*
	*/ connected share95 year if inrange(year,1962,2012), lwidth(thick) msize(large) mlc(ebblue) mfc(ebblue) lc(ebblue) || /*
	*/ line mean2share95 year if inrange(year,1962,2012), lpattern("--") lwidth(thick) /*
	*/   name("wealthshare9095", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) xscale(r(1962 2012)) xlabel(1960(10)2012) xtitle("") /*
	*/ xlabel(,labsize(medlarge)) ylabel(,labsize(medlarge)) yscale(r(0 0.18)) ylabel(0.0(0.05)0.18) ytitle("") /*
	*/ legend(order(1 3) col(1) bplacement(sw) ring(0) lab(1 "share HH over 90th pct") lab(3 "share HH over 95th pct"))	
	graph export "${sav_dir}/wealthshare9095.eps" , replace
	
replace p99KS = p99KS/100000
replace p90SZ = p90SZ/100000
replace p95SZ = p95SZ/100000
replace p99SZ = p99SZ/100000

replace p90wealth = p90wealth/100000
replace p95wealth = p95wealth/100000
replace p99wealth = p99wealth/100000

restore

/* Compare wealth levels within the top 1% */
import excel using "${data_dir}/tax_data/Top1Thresholds.xlsx", sheet("AverageWealth") cellrange(A2:F64) clear

/* Nominal dollars */
rename A year
rename B wealthall
rename C wealthbottom90
rename D wealthtop10
rename E wealthtop5
rename F wealthtop1

merge 1:1 year using "${data_dir}/CPI_PCE.dta" 
keep if year >= 1950 & year <= 2012

/* Transform to 2016 dollars */
replace wealthall = wealthall / CPI
replace wealthbottom90 = wealthbottom90 / CPI
replace wealthtop10 = wealthtop10 / CPI
replace wealthtop5 = wealthtop5 / CPI
replace wealthtop1 = wealthtop1 / CPI

drop CPI _merge

merge 1:1 year using `pensionshare' 

replace wealthbottom90 = wealthbottom90 * (1 - psharebottom90)
replace wealthtop10    = wealthtop10 * (1 - psharetop10)
replace wealthtop5     = wealthtop5 * (1 - psharetop5)
replace wealthtop1     = wealthtop1 * (1 - psharetop1)

drop _merge

save `taxlevels' , replace

/* Compare wealth levels within the top 1% */
use "${data_dir}/SCF_plus.dta", clear

/* Make wealth data comparable by subtracting pensions */
gen ffanwno = ffanw - pen

/* Merge in percentiles from tax data */
merge m:1 yearmerge using `taxpercentiles'
drop _merge

/* Average income for households above the 99th percentile from the tax data */
preserve
drop if ffanwno < p99SZ 

collapse ffanwno [aw = wgtI95W95 ], by(yearmerge)

rename yearmerge year
merge 1:1 year using `taxlevels'
drop _merge
sort year

replace ffanwno = ffanwno/1000000
replace wealthtop1 = wealthtop1/1000000

twoway connected ffanwno year if inrange(year,1962,2012), lwidth(thick) msize(vlarge) mlc(gs0) mfc(gs0) || line wealthtop1 year if inrange(year,1962,2012), lpattern("--") lc(blue) lwidth(thick) /*
	*/   name("wealthleveltop1", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) xscale(r(1961 2014)) xlabel(1961(10)2014) xtitle("") /*
	*/   yscale(r(0 16)) ylabel(0(2)15) ytitle("millions", size(medlarge)) /*
	*/ xlabel(,labsize(medlarge)) ylabel(,labsize(medlarge)) legend(bplacement(nw) ring(0)  lab(1 "SCF+") lab(2 "Capitalized tax data"))
graph export "${sav_dir}/wealthleveltop1.eps" , replace
	
restore

********************************************************************************
* Figures B.7 + D.11
********************************************************************************

clear
window manage close graph _all
set more off
set trace off

use "${data_dir}/SCF_plus.dta" , clear
tempfile condmeans wealthmeans incomemeans incomemeansincomedist
mi unset , asis
cap drop _merge
 
preserve

collapse (p50) p50wealth = ffanw p50income = tinc /*
*/ (p90) p90wealth = ffanw p90income = tinc (p99) p99wealth = ffanw p99income = tinc [aw = wgtI95W95], by(yearmerge) 
save `condmeans' , replace

restore

/* Assets, debt and wealth by wealth groups */
preserve
merge m:1 yearmerge using `condmeans'

gen wealthgroup = 1 + (ffanw > p50wealth) + (ffanw > p90wealth)
drop if ffanw >= . 

collapse ffanw ffaass tdebt  [aw = wgtI95W95], by(yearmerge wealthgroup) 

reshape wide ffanw ffaass tdebt , i(yearmerge) j(wealthgroup)
save `wealthmeans', replace

restore

/* Income by wealth groups */
preserve
merge m:1 yearmerge using `condmeans'

gen wealthgroup = 1 + (ffanw > p50wealth) + (ffanw > p90wealth)
//gen incomegroup = 1 + (tinc > p50income) + (tinc > p90income)

drop if tinc >= . 
collapse tinc [aw = wgtI95W95], by(yearmerge wealthgroup) 

reshape wide tinc, i(yearmerge) j(wealthgroup)
save `incomemeans', replace
restore  
  
 /* Income by income groups */
preserve
merge m:1 yearmerge using `condmeans'

gen incomegroup = 1 + (tinc > p50income) + (tinc > p90income)

drop if tinc >= . 
collapse tinc [aw = wgtI95W95], by(yearmerge incomegroup) 

reshape wide tinc, i(yearmerge) j(incomegroup)
rename tinc* tincinc*
save `incomemeansincomedist', replace

restore  
 
 /* Income and wealth ratios that are unaffected by impuation at the top. 
    We impute 2% of households within the top 5% of the income and wealth 
	distribution so that all households below the 95th percentile will remain 
	unaffected */
collapse /*
*/ (p50) p50wealth = ffanw p50income = tinc /*
*/ (p90) p90wealth = ffanw p90income = tinc /*
*/ (p95) p95wealth = ffanw p95income = tinc /*
*/ (p99) p99wealth = ffanw p99income = tinc /*
*/ [aw = wgtI95W95], by(yearmerge) 
 
/* Merge in means to percentiles */
/* Income and wealth levels by wealth groups */	
merge 1:1 yearmerge using `incomemeans'
drop _merge
merge 1:1 yearmerge using `wealthmeans'
drop _merge

gen meanwealth = ffanw3/ffanw2 
quietly : sum meanwealth if yearmerge == 1971
gen meanwealth_I1971 = meanwealth/`r(mean)' 

gen meanincome = tinc3/tinc2  
quietly : sum meanincome if yearmerge == 1971
gen meanincome_I1971 = meanincome/`r(mean)' 
 
/* Growth of percentile ratios */
foreach qrat in "9550" "9050" {

	foreach cvar in "wealth" "income" {
		local fp = substr("`qrat'",1,2)
		local lp = substr("`qrat'",3,2)
		cap drop p`fp'`lp'`cvar'*
		gen p`fp'`lp'`cvar' = p`fp'`cvar'/p`lp'`cvar'
		quietly : sum p`fp'`lp'`cvar' if yearmerge == 1971
		gen p`fp'`lp'`cvar'_I1971 = p`fp'`lp'`cvar'/`r(mean)'
		}

	twoway line p`qrat'wealth_I1971 yearmerge , lwidth(thick) lp("l") || line p`qrat'income_I1971 yearmerge , lwidth(thick) lp("--") lc(blue) /*
	*/ name("RD`qrat'trend_I1971", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) /*
	*/ xscale(r(1949 2017)) xlabel(1950(5)2015) xtitle("") /*title("change in `qrat'-ratio to 1971")*/ /*
	*/ legend(bplacement(nw) ring(0) col(1)  lab(1 "wealth") lab(2 "income") )
	graph export  "${sav_dir}/QR`qrat'trend_I1971.eps", replace
	
	}
	
/* Only medians within groups (note income is wrt to income distribution) */
foreach cvar in "wealth" "income" {
	foreach qt in "99" "95" "90" {
		quietly : sum p`qt'`cvar' if yearmerge == 1971
		gen p`qt'`cvar'_I1971 = p`qt'`cvar'/`r(mean)'	
		}	
	}
	
/* Income and wealth levels by wealth groups */	
merge 1:1 yearmerge using `incomemeans'
drop _merge
merge 1:1 yearmerge using `wealthmeans'
drop _merge
merge 1:1 yearmerge using `incomemeansincomedist'

/*
 Naming convention 
tincinc :  by income groups, 
tinc  : by wealth groups 
*/

foreach cvar in "ffanw" "tincinc" {
	forvalues i = 1(1)3 {
		quietly : sum `cvar'`i' if yearmerge == 1971
		cap drop `cvar'`i'_I1971
		gen `cvar'`i'_I1971 = `cvar'`i'/`r(mean)'
		}	
	}
 
twoway line p95wealth_I1971 yearmerge, lwidth(thick) lp("_") lc(blue) /*
	*/ || line p99wealth_I1971 yearmerge, lwidth(thick) lp("--") lc(red) || line p90wealth_I1971 yearmerge, lwidth(thick) lp("l") /*
	*/ name("Cwealthtrend_I1971", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) /*title("change in wealth to 1971")*/ /*
	*/ xscale(r(1949 2017)) xlabel(1950(5)2015) xtitle("") /*
	*/ legend(bplacement(nw) ring(0) col(1)  order(3 1 2) lab(1 "95th percentile") lab(2 "99th percentile") lab(3 "90th percentile")  )
	graph export "${sav_dir}/withintop10_wealth.eps", replace
	
twoway line p95income_I1971 yearmerge, lwidth(thick) lp("_") lc(blue) /*
	*/ || line p99income_I1971 yearmerge, lwidth(thick) lp("--") lc(red) || line p90income_I1971 yearmerge , lwidth(thick) lp("l") /*
	*/ name("Cincometrend_I1971", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) /*title("change in income to 1971")*/ /* 
	*/ xscale(r(1949 2017)) xlabel(1950(5)2015) xtitle("") /*
	*/ legend(bplacement(nw) ring(0) col(1) order(3 1 2) lab(1 "95th percentile") lab(2 "99th percentile") lab(3 "90th percentile")  )
graph export "${sav_dir}/withintop10_income.eps", replace

gen p90wealthL = p90wealth/10000
gen p95wealthL = p95wealth/50000
gen p99wealthL = p99wealth/100000

twoway line p90wealthL yearmerge , lwidth(thick) lp("l") ||  line p95wealthL yearmerge , lwidth(thick) lp("_") lc(blue) || /*
*/ line p99wealthL yearmerge , lwidth(thick) lp("--") lc(red)  /*
*/ name("wealthpctlevel", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) /* 
*/ xscale(r(1949 2017)) xlabel(1950(5)2015) xtitle("") /*
*/ legend(bplacement(nw) ring(0) col(1) lab(1 "90th percentile (in 10,000)") lab(2 "95th percentile (in 50,000)") lab(3 "99th percentile (in 100,000)"))
graph export "${sav_dir}/top10percentiles_wealth.eps", replace

gen p90incomeL = p90income/1000
gen p95incomeL = p95income/1000
gen p99incomeL = p99income/5000

twoway line p90incomeL yearmerge , lwidth(thick) lp("l") ||  line p95incomeL yearmerge , lwidth(thick) lp("_") lc(blue) || /*
*/ line p99incomeL yearmerge , lwidth(thick) lp("--") lc(red)  /*
*/ name("incomepctlevel", replace) scheme(s2mono) graphregion(color(white)) bgcolor(white) /* 
*/ xscale(r(1949 2017)) xlabel(1950(5)2015) xtitle("") /*
*/ legend(bplacement(nw) ring(0) col(1) lab(1 "90th percentile (in 1,000)") lab(2 "95th percentile (in 1,000)") lab(3 "99th percentile (in 5,000)"))
graph export "${sav_dir}/top10percentiles_income.eps", replace

********************************************************************************
* Figures D.9 + D.10 + E.13
********************************************************************************
clear all

qui use "${data_dir}/SCF_plus.dta", clear

qui gen imputed_rent = house * housing_rent_yd
qui egen tinc_imp_rent = rowtotal(tinc imputed_rent)
qui gen tinc_pos = tinc if tinc > 0 & !mi(tinc)
qui gen ffanw_pos = ffanw if ffanw > 0 & !mi(ffanw)

replace ffaequ = ffaequ + mfun
qui gen liqbndofin = liqcer + bnd + ofin + pen + life
qui gen houseonfin = house + vehi + onfin + oest
qui gen equbus = ffaequ + ffabus
	
qui levelsof yearmerge, clean local(myears)

	foreach gvar in tinc tinc_pos tinc_imp ffanw ffanw_pos houseonfin equbus liqbndofin { 

	qui gen gini_`gvar' = .

		foreach myear of local myears {

		sgini `gvar' [aw=wgtI95W95] if yearmerge == `myear'
		qui replace gini_`gvar' = r(coeff) if yearmerge == `myear'

		} //	
		
	} // gvar

qui collapse gini_*, by(yearmerge) // summarize

twoway ///
connected gini_tinc yearmerge, lc(gs0) msym(o) msize(medlarge) mfc(gs0) mlc(gs0) || ///
connected gini_tinc_imp yearmerge, lc(blue) msym(s) msize(medium) mfc(blue) mlc(blue) ///
plotregion(color(white)) graphregion(color(white)) bgcolor(white) ytitle("") xtitle("") ///
legend( lab(1 "original") lab(2 "plus imputed rent")) ///
xlabel(1950(5)2015, angle(45)) ylabel(0.35(0.05)0.6, angle(0)) name("gini_tinc_imp_rent", replace)
graph export "${sav_dir}/gini_tinc_imp_rent.eps", replace	

twoway ///
connected gini_tinc yearmerge, lc(gs0) msym(o) msize(medlarge) mfc(gs0) mlc(gs0) || ///
connected gini_tinc_pos yearmerge, lc(blue) msym(s) msize(medium) mfc(blue) mlc(blue) ///
plotregion(color(white)) graphregion(color(white)) bgcolor(white) ytitle("") xtitle("") ///
legend( lab(1 "all incomes") lab(2 "only positive incomes")) ///
xlabel(1950(5)2015, angle(45)) ylabel(0.35(0.05)0.6, angle(0)) name("income_gini_positive", replace)
graph export "${sav_dir}/income_gini_positive.eps", replace	

twoway ///
connected gini_ffanw yearmerge, lc(gs0) msym(o) msize(medlarge) mfc(gs0) mlc(gs0) || ///
connected gini_ffanw_pos yearmerge, lc(blue) msym(s) msize(medium) mfc(blue) mlc(blue) ///
plotregion(color(white)) graphregion(color(white)) bgcolor(white) ytitle("") xtitle("") ///
legend( lab(1 "all wealth") lab(2 "only positive wealth")) ///
xlabel(1950(5)2015, angle(45)) ylabel(0.65(0.05)0.95, angle(0)) name("wealth_gini_positive", replace)
graph export "${sav_dir}/wealth_gini_positive.eps", replace

twoway ///
connected gini_equbus yearmerge, lc(gs0) msym(o) msize(medlarge) mfc(gs0) mlc(gs0) || ///
connected gini_liqbndofin yearmerge, lc(blue) msym(s) msize(medium) mfc(blue) mlc(blue) || ///
connected gini_houseonfin yearmerge, lc(red) msym(d) msize(medlarge) mfc(red) mlc(red) ///
plotregion(color(white)) graphregion(color(white)) bgcolor(white) ytitle("") xtitle("") ///
legend( lab(1 "stocks + business") lab(2 "bonds + liquid and oth. fin. assets") lab(3 "housing + non-fin. assets")) ///
xlabel(1950(5)2015, angle(45)) ylabel(0.6(0.1)1, angle(0)) name("ginibyasset", replace)
graph export "${sav_dir}/ginibyasset.eps", replace

********************************************************************************
* Table E.3
********************************************************************************

export excel yearmerge gini* using ${sav_dir}/ginis_different_assets, sheetreplace firstrow(var)

********************************************************************************
* Figure E.14
********************************************************************************
clear all

qui use "${data_dir}/SCF_plus.dta", clear

qui collapse house ffaass tdebt ffanw [aw=wgtI95W95], by(yearmerge ffanwgroups)

qui gen div = house/ffaass * 100
qui gen lev = tdebt/ffanw * 100

twoway ///
connected div yearmerge if ffanwgroups == 1, lc(gs0) msym(o) msize(medlarge) mfc(gs0) mlc(gs0) || ///
connected div yearmerge if ffanwgroups == 2, lc(blue) msym(s) msize(medium) mfc(blue) mlc(blue) || ///
connected div yearmerge if ffanwgroups == 3, lc(red) msym(d) msize(medium) mfc(red) mlc(red) ///	
plotregion(color(white)) graphregion(color(white)) bgcolor(white) ytitle("") xtitle("") ///
legend( lab(1 "0% - 50%") lab(2 "50% - 90%") lab(3 "Top 10%") row(1) symxsize(7) ) ///
xlabel(1950(5)2015, angle(45)) ylabel(0(20)80, angle(0)) name("div_all", replace)
graph export "${sav_dir}/div_all.eps", replace	

twoway ///
connected div yearmerge if ffanwgroups == 2, lc(blue) msym(s) msize(medium) mfc(blue) mlc(blue) || ///
connected div yearmerge if ffanwgroups == 3, lc(red) msym(d) msize(medium) mfc(red) mlc(red) ///	
plotregion(color(white)) graphregion(color(white)) bgcolor(white) ytitle("") xtitle("") ///
legend( lab(1 "50% - 90%") lab(2 "Top 10%") row(1) symxsize(7) ) ///
xlabel(1950(5)2015, angle(45)) ylabel(0(20)80, angle(0)) name("div_mid_top", replace)
graph export "${sav_dir}/div_mid_top.eps", replace	

twoway ///
connected lev yearmerge if ffanwgroups == 1, lc(gs0) msym(o) msize(medlarge) mfc(gs0) mlc(gs0) || ///
connected lev yearmerge if ffanwgroups == 2, lc(blue) msym(s) msize(medium) mfc(blue) mlc(blue) || ///
connected lev yearmerge if ffanwgroups == 3, lc(red) msym(d) msize(medium) mfc(red) mlc(red) ///	
plotregion(color(white)) graphregion(color(white)) bgcolor(white) ytitle("") xtitle("") ///
legend( lab(1 "0% - 50%") lab(2 "50% - 90%") lab(3 "Top 10%") row(1) symxsize(7) ) ///
xlabel(1950(5)2015, angle(45)) ylabel(0(50)500, angle(0)) name("lev_all", replace)
graph export "${sav_dir}/lev_all.eps", replace	

twoway ///
connected lev yearmerge if ffanwgroups == 2, lc(blue) msym(s) msize(medium) mfc(blue) mlc(blue) || ///
connected lev yearmerge if ffanwgroups == 3, lc(red) msym(d) msize(medium) mfc(red) mlc(red) ///	
plotregion(color(white)) graphregion(color(white)) bgcolor(white) ytitle("") xtitle("") ///
legend( lab(1 "50% - 90%") lab(2 "Top 10%") row(1) symxsize(7) ) ///
xlabel(1950(5)2015, angle(45)) ylabel(0(5)30, angle(0)) 

********************************************************************************
* Table E.4
********************************************************************************

qui use ${data_dir}/SCF_plus.dta, clear
mi unset, asis

rename tincgroups incomegroups
rename ffanwgroups wealthgroups

* shares in income by income groups and wealth by wealth groups
	foreach var in tinc ffanw { 
	
		if "`var'" == "tinc" {
		local vname = "income"
		} // if
		else if "`var'" == "ffanw" {
		local vname = "wealth"
		} // else
	
	preserve

	qui bysort yearmerge: egen double `var'sum = total(`var'*wgtI95W95)
	qui bysort yearmerge `vname'groups: egen double `var'sum_group = total(`var'*wgtI95W95)
	qui gen `var'_share = round(`var'sum_group/`var'sum*100, 0.1)

	qui collapse `var'_share, by(yearmerge `vname'groups) // summarize

	reshape wide `var'_share, i(yearmerge) j(`vname'groups)

	export excel _all using "${sav_dir}/`vname'shares.xlsx", ///
	firstrow (var) sheet(by`vname') sheetreplace
	
	restore

	} // var
	
* shares in income by wealth groups and wealth by income groups	
	foreach var in tinc ffanw {
	
		if "`var'" == "tinc" {
		local vname = "income"
		local vgroupname = "wealth"
		} // if
		else if "`var'" == "ffanw" {
		local vname = "wealth"
		local vgroupname = "income"
		} // else
	
	preserve

	qui bysort yearmerge: egen double `var'sum = total(`var'*wgtI95W95)
	qui bysort yearmerge `vgroupname'groups: egen double `var'sum_group = total(`var'*wgtI95W95)
	qui gen `var'_share = round(`var'sum_group/`var'sum*100, 0.1)

	qui collapse `var'_share, by(yearmerge `vgroupname'groups) // summarize

	reshape wide `var'_share, i(yearmerge) j(`vgroupname'groups)

	export excel _all using "${sav_dir}/`vname'shares.xlsx", ///
	firstrow (var) sheet(by`vgroupname') sheetreplace
	
	restore

	} // var

********************************************************************************
* Table C.2
********************************************************************************
	
clear	
	
do "${data_dir}/PSID_data/J252489.do"

* Rename variables 
quietly {

rename ER30001 id
rename ER30002 person

rename V81 income1968
rename V529 income1969
rename V1514 income1970
rename V2226 income1971
rename V2852 income1972
rename V3256 income1973
rename V3676 income1974
rename V4154 income1975
rename V5029 income1976
rename V5626 income1977
rename V6173 income1978
rename V6766 income1979
rename V7412 income1980
rename V8065 income1981
rename V8689 income1982
rename V9375 income1983
rename V11022 income1984
rename V12371 income1985
rename V13623 income1986
rename V14670 income1987
rename V16144 income1988
rename V17533 income1989
rename V18875 income1990
rename V20175 income1991
rename V21481 income1992
rename V23322 income1993
rename ER4153 income1994
rename ER6993 income1995
rename ER9244 income1996
rename ER12079 income1997
rename ER16462 income1999
rename ER20456 income2001
rename ER24099 income2003
rename ER28037 income2005
rename ER41027 income2007
rename ER46935 income2009
rename ER52343 income2011
rename ER58152 income2013
rename ER65349 income2015

rename V117 ageh1968
rename V1008 ageh1969
rename V1239 ageh1970
rename V1942 ageh1971
rename V2542 ageh1972
rename V3095 ageh1973
rename V3508 ageh1974
rename V3921 ageh1975
rename V4436 ageh1976
rename V5350 ageh1977
rename V5850 ageh1978
rename V6462 ageh1979
rename V7067 ageh1980
rename V7658 ageh1981
rename V8352 ageh1982
rename V8961 ageh1983
rename V10419 ageh1984
rename V11606 ageh1985
rename V13011 ageh1986
rename V14114 ageh1987
rename V15130 ageh1988
rename V16631 ageh1989
rename V18049 ageh1990
rename V19349 ageh1991
rename V20651 ageh1992
rename V22406 ageh1993
rename ER2007 ageh1994
rename ER5006 ageh1995
rename ER7006 ageh1996
rename ER10009 ageh1997
rename ER13010 ageh1999
rename ER17013 ageh2001
rename ER21017 ageh2003
rename ER25017 ageh2005
rename ER36017 ageh2007
rename ER42017 ageh2009
rename ER47317 ageh2011
rename ER53017 ageh2013
rename ER60017 ageh2015

rename S117 wealth1984
rename S217 wealth1989
rename S317 wealth1994
rename S417 wealth1999
rename S517 wealth2001
rename S617 wealth2003
rename S717 wealth2005
rename S817 wealth2007
rename ER46970 wealth2009
rename ER52394 wealth2011
rename ER58211 wealth2013

rename S117A IMP_wealth1984
rename S217A IMP_wealth1989
rename S317A IMP_wealth1994
rename S417A IMP_wealth1999
rename S517A IMP_wealth2001
rename S617A IMP_wealth2003
rename S717A IMP_wealth2005
rename S817A IMP_wealth2007
rename ER46971 IMP_wealth2009
rename ER52395 IMP_wealth2011
rename ER58212 IMP_wealth2013

rename ER30003 relhead1968
rename ER30022  relhead1969
rename ER30045  relhead1970
rename ER30069  relhead1971
rename ER30093  relhead1972
rename ER30119  relhead1973
rename ER30140  relhead1974
rename ER30162  relhead1975
rename ER30190  relhead1976
rename ER30219  relhead1977
rename ER30248  relhead1978
rename ER30285  relhead1979
rename ER30315  relhead1980
rename ER30345  relhead1981
rename ER30375  relhead1982
rename ER30401  relhead1983
rename ER30431  relhead1984
rename ER30465  relhead1985
rename ER30500  relhead1986
rename ER30537  relhead1987
rename ER30572  relhead1988
rename ER30608  relhead1989
rename ER30644  relhead1990
rename ER30691  relhead1991
rename ER30735  relhead1992
rename ER30808  relhead1993
rename ER33103  relhead1994
rename ER33203  relhead1995
rename ER33303  relhead1996
rename ER33403  relhead1997
rename ER33503  relhead1999
rename ER33603  relhead2001
rename ER33703  relhead2003
rename ER33803  relhead2005
rename ER33903  relhead2007
rename ER34003  relhead2009
rename ER34103  relhead2011
rename ER34203  relhead2013
rename ER34303 relhead2015

gen seqnum1968 = 1
rename ER30021  seqnum1969
rename ER30044  seqnum1970
rename ER30068  seqnum1971
rename ER30092  seqnum1972
rename ER30118  seqnum1973
rename ER30139  seqnum1974
rename ER30161  seqnum1975
rename ER30189  seqnum1976
rename ER30218  seqnum1977
rename ER30247  seqnum1978
rename ER30284  seqnum1979
rename ER30314  seqnum1980
rename ER30344  seqnum1981
rename ER30374  seqnum1982
rename ER30400  seqnum1983
rename ER30430  seqnum1984
rename ER30464  seqnum1985
rename ER30499  seqnum1986
rename ER30536  seqnum1987
rename ER30571  seqnum1988
rename ER30607  seqnum1989
rename ER30643  seqnum1990
rename ER30690  seqnum1991
rename ER30734  seqnum1992
rename ER30807  seqnum1993
rename ER33102  seqnum1994
rename ER33202  seqnum1995
rename ER33302  seqnum1996
rename ER33402  seqnum1997
rename ER33502  seqnum1999
rename ER33602  seqnum2001
rename ER33702  seqnum2003
rename ER33802  seqnum2005
rename ER33902  seqnum2007
rename ER34002  seqnum2009
rename ER34102  seqnum2011
rename ER34202  seqnum2013
rename ER34302 seqnum2015
}

* Sample selection 
drop if inrange(id,3000,9308) // SRC sample, do not use weights in this case
//drop if inrange(id,5000,9308) // Drop Latino and SEO sample as in Kaplan, Violante, Weidner

keep income* ageh* wealth* id person relhead* seqnum* /*fwgt**/

egen seqid = seq()
quietly : reshape long income ageh wealth relhead seqnum, i(seqid) j(year)

/* Keep only head of household observations */
gen currenthead = 0
replace currenthead = 1 if relhead == 1 & year == 1968 
replace currenthead = 1 if relhead == 1 & inrange(seqnum,1,20) & inrange(year,1969,1982)
replace currenthead = 1 if relhead == 10 & inrange(seqnum,1,20) & inrange(year,1983,2015)
keep if currenthead == 1

replace year = year - 1

keep  income ageh wealth seqid year /*house*/

quietly : reshape wide income ageh wealth /*house*/, i(seqid) j(year)

numlist "1967(1)1995 1996(2)2014" , integer ascending
//numlist "1982(1)1995 1996(2)2014" , integer ascending
local yearlist = "`r(numlist)'"
local nyears : word count `yearlist' 

/* Define quintiles to be used later */
forvalues yi = 1(1)`nyears'  { 
	local cyear = word("`yearlist'",`yi')
	//display "`cyear'"
	quietly {
		 xtile income_quint`cyear' = income`cyear' if income`cyear' < . , nq(5)
		 if(inlist(`cyear',1983,1988,1993,1998,2000,2002,2004,2006,2008,2010,2012)) {
			 xtile wealth_quint`cyear' = wealth`cyear' if wealth`cyear' < . , nq(5)
			 }
		 }
	}

* Define the three wealth and income groups 
quietly {
	forvalues yi = 1(1)`nyears'  { 
		local fyear = word("`yearlist'",`yi')
		
		foreach cvar in "wealth" "income" {
			if(inlist(`fyear',1983,1988,1993,1998,2000,2002,2004,2006,2008,2010,2012)) {
				quietly : sum `cvar'`fyear' , d
				local q50 = `r(p50)'
				local q90 = `r(p90)'
					
				gen `cvar'bottom50_`fyear' = (`cvar'`fyear' <= `q50'  )
				replace `cvar'bottom50_`fyear' =  . if `cvar'`fyear' >= . 
				 
				gen `cvar'top10_`fyear' = (`cvar'`fyear' > `q90' & `cvar'`fyear' < .)
				replace `cvar'top10_`fyear' =  . if `cvar'`fyear' >= .  
				 
				gen `cvar'middle5090_`fyear' = 1 - `cvar'bottom50_`fyear'  -  `cvar'top10_`fyear' if `cvar'`fyear' < .
				replace `cvar'middle5090_`fyear' =  . if `cvar'`fyear' >= .  
				
				} 
			}
		}
	}

* Wealth and income persistence over time
	
matrix wealthpersistence = J(3,10,.)
matrix rownames wealthpersistence = "bottom 50" "50-90" "top 10"
matrix colnames wealthpersistence = "1983" "1988" "1993" "1998" "2000" "2002" "2004" "2006" "2008" "2010" 

gen totalobs = 0
gen wealthbottom50 = 0
gen wealthmiddle5090 = 0
gen wealthtop10 = 0
gen wealthtop20 = 0

numlist "1983(5)1998 2000(2)2010" , integer ascending
local wealthyearlist = "`r(numlist)'"
local wnyears : word count `wealthyearlist' 

local ci = 0
forvalues yi = 1(1)`wnyears'  { 
	local fyear = word("`wealthyearlist'",`yi')
	local lyear = `fyear' + 2 + 3 * (`fyear' <= 1993)
	local ci = `ci' + 1
	
	display "`fyear' => `lyear'"
	
	quietly {
		replace totalobs = totalobs + (wealth`fyear' < .)
		
		count if wealthbottom50_`fyear' == 1 &  wealthbottom50_`lyear' <= 1 
		local denom = `r(N)'
		count if wealthbottom50_`fyear' == 1 &  wealthbottom50_`lyear' == 1   
		local numb = `r(N)'
		count if wealthbottom50_`fyear' == 1 &  wealthbottom50_`lyear' < 1   
		local alt = `r(N)'
		
		replace wealthbottom50 = wealthbottom50 + wealthbottom50_`fyear'
		
		matrix wealthpersistence[1 , `ci'] = `numb'/`denom'

		count if wealthmiddle5090_`fyear' == 1 & wealthmiddle5090_`lyear' <= 1 
		local denom = `r(N)'
		count if wealthmiddle5090_`fyear' == 1 & wealthmiddle5090_`lyear' == 1   
		local numb = `r(N)'
		count if wealthmiddle5090_`fyear' == 1 & wealthmiddle5090_`lyear' < 1   
		local alt = `r(N)'

		replace wealthmiddle5090 = wealthmiddle5090 + wealthmiddle5090_`fyear'
		
		matrix wealthpersistence[2 , `ci'] = `numb'/`denom'
		
		//noisily display "`fyear' 50% - 90%: `numb' out of `denom' (other `alt')"
		
		count if wealthtop10_`fyear' == 1 & wealthtop10_`lyear' <= 1   
		local denom = `r(N)'
		count if wealthtop10_`fyear' == 1 & wealthtop10_`lyear' == 1   
		local numb = `r(N)'
		count if wealthtop10_`fyear' == 1 & wealthtop10_`lyear' < 1   
		local alt = `r(N)'
		
		replace wealthtop10 = wealthtop10 + wealthtop10_`fyear'
		
		replace wealthtop20 = wealthtop20 + (wealth_quint`fyear' == 5)
		
		matrix wealthpersistence[3 , `ci'] = `numb'/`denom'

		}
	}

matrix list wealthpersistence
